<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//pl_PL

$LANG=array();


$LANG['backup'][0]="Zrzut SQL"; 
$LANG['backup'][1]="Zrzut XML"; 
$LANG['backup'][11]="Rozmiar"; 
$LANG['backup'][13]="Zobacz/Ściągnij"; 
$LANG['backup'][16]="Nadpisz obecną bazę danych plikiem z kopi zapasowej:"; 
$LANG['backup'][17]="Usuń plik"; 
$LANG['backup'][18]="Kopia bazy danych"; 
$LANG['backup'][19]="Teraz"; 
$LANG['backup'][21]="Ten plik już istnieje"; 
$LANG['backup'][22]="Nie znaleziono bajtu"; 
$LANG['backup'][23]="Błąd uruchomienia Mysql"; 
$LANG['backup'][24]="Automatyczne przekierowanie, przeciwnie kliknij"; 

$LANG['bookmark'][1]="zakładka"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Nie masz jeszcze zapisanych zakładek."; 
$LANG['bookmark'][4]="Nowa zakładka"; 
$LANG['bookmark'][5]="Opublikuj zakładki"; 
$LANG['bookmark'][6]="Zastosuj domyślne"; 

$LANG['buttons'][0]="Szukaj"; 
$LANG['buttons'][2]="Wyślij"; 
$LANG['buttons'][3]="Przypisz"; 
$LANG['buttons'][4]="Instaluj"; 
$LANG['buttons'][5]="Odinstaluj"; 
$LANG['buttons'][6]="Usuń"; 
$LANG['buttons'][7]="Uaktualnij"; 
$LANG['buttons'][8]="Dodaj"; 
$LANG['buttons'][9]="Połącz"; 
$LANG['buttons'][10]="Rozłącz"; 
$LANG['buttons'][11]="Następny"; 
$LANG['buttons'][12]="Poprzedni"; 
$LANG['buttons'][13]="Wstecz"; 
$LANG['buttons'][14]="Zmień"; 
$LANG['buttons'][15]="Zaplanuj"; 
$LANG['buttons'][16]="Pusty"; 
$LANG['buttons'][17]="Odwróć zaznaczenie"; 
$LANG['buttons'][18]="Zaznacz Wszystkie"; 
$LANG['buttons'][19]="Odznacz Wszystkie"; 
$LANG['buttons'][20]="Przenieś"; 
$LANG['buttons'][21]="Przywróć"; 
$LANG['buttons'][22]="Czyść"; 
$LANG['buttons'][23]="Pokaż"; 
$LANG['buttons'][24]="W górę"; 
$LANG['buttons'][25]="W dół"; 
$LANG['buttons'][27]="Bieżąca do PDF"; 
$LANG['buttons'][28]="Bieżąca do SLK"; 
$LANG['buttons'][29]="Wszystko do PDF"; 
$LANG['buttons'][30]="Wszystko do SLK"; 
$LANG['buttons'][31]="Eksport"; 
$LANG['buttons'][32]="Zakończ"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Anuluj"; 
$LANG['buttons'][37]="Importuj"; 
$LANG['buttons'][38]="Odblokuj"; 
$LANG['buttons'][39]="Zamień"; 
$LANG['buttons'][40]="Pokaż wszystko"; 
$LANG['buttons'][41]="Aktywuj"; 
$LANG['buttons'][42]="Deaktywuj"; 
$LANG['buttons'][43]="Przeglądaj"; 
$LANG['buttons'][44]="Bieżąca CSV"; 
$LANG['buttons'][45]="Wszystko do CSV"; 
$LANG['buttons'][46]="Wcześniej"; 
$LANG['buttons'][47]="Później"; 
$LANG['buttons'][48]="Przeniesienie"; 
$LANG['buttons'][49]="Zabezpiecz"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Zapisz"; 
$LANG['buttons'][52]="Wgraj"; 
$LANG['buttons'][53]="Wyczyść"; 
$LANG['buttons'][55]="Pierwszy"; 
$LANG['buttons'][56]="Ostatni"; 
$LANG['buttons'][57]="Wykonaj"; 
$LANG['buttons'][58]="Uaktualnij"; 
$LANG['buttons'][59]="Cofnij skojarzenie"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="Nie."; 
$LANG['calendarD'][1]="Pon."; 
$LANG['calendarD'][2]="Wt."; 
$LANG['calendarD'][3]="Śr."; 
$LANG['calendarD'][4]="Czw."; 
$LANG['calendarD'][5]="Pt."; 
$LANG['calendarD'][6]="Sob."; 

$LANG['calendarDay'][0]="Niedziela"; 
$LANG['calendarDay'][1]="Poniedziałek"; 
$LANG['calendarDay'][2]="Wtorek"; 
$LANG['calendarDay'][3]="Środa"; 
$LANG['calendarDay'][4]="Czwartek"; 
$LANG['calendarDay'][5]="Piątek"; 
$LANG['calendarDay'][6]="Sobota"; 

$LANG['calendarM'][0]="Styczeń"; 
$LANG['calendarM'][1]="Luty"; 
$LANG['calendarM'][2]="Marzec"; 
$LANG['calendarM'][3]="Kwiecień"; 
$LANG['calendarM'][4]="Maj"; 
$LANG['calendarM'][5]="Czerwiec"; 
$LANG['calendarM'][6]="Lipiec"; 
$LANG['calendarM'][7]="Sierpień"; 
$LANG['calendarM'][8]="Wrzesień"; 
$LANG['calendarM'][9]="Październik"; 
$LANG['calendarM'][10]="Listopad"; 
$LANG['calendarM'][11]="Grudzień"; 

$LANG['cartridges'][0]="Kartridż"; 
$LANG['cartridges'][7]="Kartridż nie znaleziony"; 
$LANG['cartridges'][9]="Brak kartridża"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Typ kartridża"; 
$LANG['cartridges'][13]="Nowy"; 
$LANG['cartridges'][14]="Używany"; 
$LANG['cartridges'][15]="Zużyty"; 
$LANG['cartridges'][16]="Kartridż(e)"; 
$LANG['cartridges'][20]="Nowy"; 
$LANG['cartridges'][21]="Używany"; 
$LANG['cartridges'][22]="Zużyty"; 
$LANG['cartridges'][24]="Dodaj Datę"; 
$LANG['cartridges'][27]="Włączony"; 
$LANG['cartridges'][29]="Koniec żywotności"; 
$LANG['cartridges'][32]="Typy kompatybilnych drukarek"; 
$LANG['cartridges'][33]="Używane kartridże"; 
$LANG['cartridges'][34]="Brak wolnych kartridży"; 
$LANG['cartridges'][35]="Zużyte kartridże"; 
$LANG['cartridges'][37]="Wstążka"; 
$LANG['cartridges'][39]="Licznik drukarek"; 
$LANG['cartridges'][40]="Średni Czas w rezerwie"; 
$LANG['cartridges'][41]="Średni Czas w użyciu"; 
$LANG['cartridges'][42]="Średnia liczba wydrukowanych stron"; 

$LANG['central'][2]="Ostatni/e"; 
$LANG['central'][4]="Brak zdarzeń"; 
$LANG['central'][5]="Początek"; 
$LANG['central'][6]="Wyloguj"; 
$LANG['central'][7]="Pomoc"; 
$LANG['central'][8]="Dodatki"; 
$LANG['central'][9]="Twoje rozpatrywane zlecenia"; 
$LANG['central'][10]="Nowe zgłoszenia"; 
$LANG['central'][12]="Widok osobisty"; 
$LANG['central'][13]="Widok ogólny"; 
$LANG['central'][14]="Widok Grupowy"; 
$LANG['central'][18]="Zamknięto twoje zlecenie"; 
$LANG['central'][19]="Twoje zgłoszenie jest weryfikowane"; 

$LANG['choice'][0]="Nie"; 
$LANG['choice'][1]="Tak"; 

$LANG['common'][0]="Bez nazwy"; 
$LANG['common'][1]="Pozycja"; 
$LANG['common'][2]="Lp"; 
$LANG['common'][3]="Pokaż kosz"; 
$LANG['common'][4]="Strona www"; 
$LANG['common'][5]="Producent"; 
$LANG['common'][6]="Nazwa Szablonu"; 
$LANG['common'][7]="Wybierz szablon"; 
$LANG['common'][8]="Zarządzaj szablonami"; 
$LANG['common'][9]="Dodaj szablon"; 
$LANG['common'][10]="Odpowiedzialny techniczny"; 
$LANG['common'][11]="Ograniczony widok"; 
$LANG['common'][12]="Ustawienia"; 
$LANG['common'][13]="Szablon"; 
$LANG['common'][14]="Szablony"; 
$LANG['common'][15]="Lokalizacja"; 
$LANG['common'][16]="Nazwa"; 
$LANG['common'][17]="Typ"; 
$LANG['common'][18]="Alternatywna nazwa użytkownika"; 
$LANG['common'][19]="Numer seryjny"; 
$LANG['common'][20]="Numer inwentaryzacyjny"; 
$LANG['common'][21]="Alternatywna numer kontaktowy"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operacja zakończona sukcesem"; 
$LANG['common'][24]="Brak wybranego elementu lub źle zdefiniowana operacja"; 
$LANG['common'][25]="Komentarze"; 
$LANG['common'][26]="Ostatnia aktualizacja"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Skasowany"; 
$LANG['common'][29]="Dodatki"; 
$LANG['common'][30]="Nowy element"; 
$LANG['common'][31]="Pusty szablon"; 
$LANG['common'][32]="Charakterystyka"; 
$LANG['common'][33]="Razem"; 
$LANG['common'][34]="Użytkownik"; 
$LANG['common'][35]="Grupa"; 
$LANG['common'][36]="Kategoria"; 
$LANG['common'][37]="Autor"; 
$LANG['common'][38]="Odglobalizuj"; 
$LANG['common'][39]="Zduplikuj ten element tyle razy ile ma połączeń"; 
$LANG['common'][40]="Czy na pewno chcesz odglobalizować ten element?"; 
$LANG['common'][41]="E-mail alamowy"; 
$LANG['common'][42]="Telefon komórkowy"; 
$LANG['common'][43]="Imię"; 
$LANG['common'][44]="Wartość domyślna"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Postęp"; 
$LANG['common'][48]="Nazwisko"; 
$LANG['common'][49]="Żaden"; 
$LANG['common'][50]="Na pewno chcesz usunąć ?"; 
$LANG['common'][51]="Pełna Nazwa"; 
$LANG['common'][52]="Serwer"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="Nie znaleziono pozycji"; 
$LANG['common'][55]="Jesteś pewny że chcesz usunąć ten element?"; 
$LANG['common'][56]="Środowisko standardowe"; 
$LANG['common'][57]="Tytuł"; 
$LANG['common'][58]="Maksymalna wartość"; 
$LANG['common'][59]="Globalny"; 
$LANG['common'][60]="Aktywny"; 
$LANG['common'][61]="Nieznany błąd."; 
$LANG['common'][62]="Inny"; 
$LANG['common'][63]="Błędy"; 
$LANG['common'][64]="Menager"; 
$LANG['common'][65]="Interfejs"; 
$LANG['common'][66]="Wszystko"; 
$LANG['common'][67]="Inni"; 
$LANG['common'][68]="Poziomo"; 
$LANG['common'][69]="Portretowo"; 
$LANG['common'][70]="Pozycja dodana poprawnie"; 
$LANG['common'][71]="Pozycja uaktualniona poprawnie"; 
$LANG['common'][72]="Pozycja usunięta poprawnie"; 
$LANG['common'][73]="Pozycja wyczyszczona poprawnie"; 
$LANG['common'][74]="Pozycja przywrócona poprawnie"; 
$LANG['common'][75]="Brak uprawnień do działana rekursywnego na tej lokalizacji"; 
$LANG['common'][76]="Publiczne"; 
$LANG['common'][77]="Prywatne"; 
$LANG['common'][78]="Ustaw publiczne"; 
$LANG['common'][79]="Ustaw jako prywatne"; 
$LANG['common'][80]="trwa ładowanie..."; 
$LANG['common'][81]="Nie pokazuj usuniętych pozycji"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="Brak uprawnień do wykonania tej akcji."; 
$LANG['common'][84]="Zmiana flagi zabroniona. Znaleziono połączone pozycje."; 
$LANG['common'][85]="Zmień widzialność w pododdziałach"; 
$LANG['common'][86]="Nie masz uprawnień do zmiany flag widzialności dla pododdziałów."; 
$LANG['common'][87]="Nowa karta"; 
$LANG['common'][88]="Osobisty"; 
$LANG['common'][89]="Nie zainstalowany"; 
$LANG['common'][90]="Obiekt"; 
$LANG['common'][91]="Nie mogę zmienić tego atrybutu. Jest dziedziczony z obiektu nadrzędnego."; 
$LANG['common'][92]="Alternatywna nazwa użytkownika"; 
$LANG['common'][93]="Nowy nagłówek podrzędny"; 

$LANG['computers'][0]="Partycja"; 
$LANG['computers'][1]="Procent wolnego"; 
$LANG['computers'][2]="Wolne miejsce"; 
$LANG['computers'][3]="Wymiar globalny"; 
$LANG['computers'][4]="Plik systemowy"; 
$LANG['computers'][5]="Punkt montowania"; 
$LANG['computers'][6]="Partycja"; 
$LANG['computers'][7]="Dodaj wolumin"; 
$LANG['computers'][8]="Partycja"; 
$LANG['computers'][9]="System operacyjny"; 
$LANG['computers'][10]="Serial systemu operacyjnego"; 
$LANG['computers'][11]="Build systemu operacyjnego"; 
$LANG['computers'][14]="Wstawione"; 
$LANG['computers'][23]="Typ pamięci"; 
$LANG['computers'][24]="Pamięć (MB)"; 
$LANG['computers'][25]="Rozmiar HDD"; 
$LANG['computers'][36]="Typ HDD"; 
$LANG['computers'][37]="Monitor nie podłączony"; 
$LANG['computers'][38]="Drukarka nie podłączona"; 
$LANG['computers'][39]="Drukarki"; 
$LANG['computers'][40]="Monitory"; 
$LANG['computers'][46]="Urządzenia"; 
$LANG['computers'][47]="Urządzenie nie podłączone"; 
$LANG['computers'][48]="Położenie uaktualnione. Podłączone pozycje zostały przeniesione do tego samego położenia."; 
$LANG['computers'][49]="Kontakt uaktualniony. Podłączone pozycje zostały uaktualnione z użyciem tego alternatywnego kontaktu."; 
$LANG['computers'][50]="Użytkownik lub grupa odświeżona. Pozycje połączone zostały z tymi samymi wartościami."; 
$LANG['computers'][51]="Uaktualnij źródło"; 
$LANG['computers'][52]="Wersja systemu operacyjnego"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Telefon nie podłączony"; 
$LANG['computers'][55]="Telefon(y)"; 
$LANG['computers'][56]="Status uaktualniony. Połączone pozycje zostały uaktualnione do tego statusu."; 

$LANG['connect'][0]="Połączenie Bezpośrednie"; 
$LANG['connect'][1]="Nie połączony"; 
$LANG['connect'][15]="Automatyczne uaktualnienie powiązanych elementów"; 
$LANG['connect'][16]="UWAGA!!! Powiązane elementy ze sprzętem nie pasują"; 

$LANG['consumables'][0]="Materiały eksploatacyjne"; 
$LANG['consumables'][1]="Na magazynie"; 
$LANG['consumables'][2]="Odniesienie"; 
$LANG['consumables'][7]="Nie znaleziono materiału eksploatacyjnego"; 
$LANG['consumables'][9]="Brak materiału eksploatacyjnego"; 
$LANG['consumables'][12]="Typy materiałów eksploatacyjnych"; 
$LANG['consumables'][13]="Nowe"; 
$LANG['consumables'][15]="Używane"; 
$LANG['consumables'][16]="Materiał(y) Eksploatacyjne(y)"; 
$LANG['consumables'][20]="Nowe"; 
$LANG['consumables'][22]="Używane"; 
$LANG['consumables'][23]="Stan"; 
$LANG['consumables'][26]="Użyj daty"; 
$LANG['consumables'][32]="Daj"; 
$LANG['consumables'][35]="Użyte materiały eksploatacyjne"; 
$LANG['consumables'][36]="Miejsce składowania"; 
$LANG['consumables'][37]="Powrót do magazynu"; 
$LANG['consumables'][38]="Próg alarmu"; 

$LANG['contract'][0]="Kontrakty wygasłe od czasu"; 
$LANG['contract'][1]="Kontrakty z uwagami od czasu"; 

$LANG['crontask'][0]="Akcje automatyczne"; 
$LANG['crontask'][1]="Synchronizuj urządzenia z OCS Inventory NG"; 
$LANG['crontask'][2]="Wyślij alarm o kartridżach"; 
$LANG['crontask'][3]="Wyślij alarm na cześciach"; 
$LANG['crontask'][4]="Wysyłaj alarmy o wygaśnietych licencjach"; 
$LANG['crontask'][5]="Wysyłaj alarmy o umowach"; 
$LANG['crontask'][6]="Wyślij alarm informacji finansowych"; 
$LANG['crontask'][7]="Wyczyść stare logi"; 
$LANG['crontask'][8]="Optymalizacja bazy danych"; 
$LANG['crontask'][9]="Odzyskane email-e ( Odbiorcy emaili)"; 
$LANG['crontask'][10]="Sprawdz replikę MySQL"; 
$LANG['crontask'][11]="Sprawdz nowe uaktualnienia"; 
$LANG['crontask'][12]="Wyczyść stare sesje"; 
$LANG['crontask'][13]="Wyczyść wygenerowane grafiki"; 
$LANG['crontask'][14]="Automatyczne zamykanie zgłoszeń"; 
$LANG['crontask'][15]="Nie rozwiązane zlecenia"; 
$LANG['crontask'][31]="Wyłączone"; 
$LANG['crontask'][32]="Zaplanowane"; 
$LANG['crontask'][33]="Uruchomione"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Uruchom tryb"; 
$LANG['crontask'][37]="Uruchom czestotliwość"; 
$LANG['crontask'][38]="Uruchamiaj cyklicznie"; 
$LANG['crontask'][39]="Ilość emaili do odzyskania"; 
$LANG['crontask'][40]="Ostatnio uruchomiony"; 
$LANG['crontask'][41]="Uruchom następne"; 
$LANG['crontask'][42]="Tak szybko jak to możliwe"; 
$LANG['crontask'][43]="Brak oczekujących zadań"; 
$LANG['crontask'][44]="Koniec zadania, cześciowo wykonane"; 
$LANG['crontask'][45]="Zadanie zakończone, pełne przetworzenie"; 
$LANG['crontask'][46]="Koniec zadania, nic do roboty"; 
$LANG['crontask'][47]="Ostatnia uruchomiona lista"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Uruchom licznik"; 
$LANG['crontask'][51]="Minimalny czas"; 
$LANG['crontask'][52]="Maksymalny czas"; 
$LANG['crontask'][53]="Średni czas"; 
$LANG['crontask'][55]="Minimalna wartość"; 
$LANG['crontask'][56]="Maksymalna wartość"; 
$LANG['crontask'][57]="Średnia wartość"; 
$LANG['crontask'][58]="wszystkie"; 
$LANG['crontask'][59]="Średnia prędkość"; 
$LANG['crontask'][60]="System zablokowany"; 
$LANG['crontask'][61]="Wyłącz wtyczkę"; 
$LANG['crontask'][62]="Elementy"; 

$LANG['devices'][0]="Dodaj nowy komponent"; 
$LANG['devices'][1]="Dysk Twardy"; 
$LANG['devices'][2]="Karty Graficzne"; 
$LANG['devices'][3]="Karta sieciowa"; 
$LANG['devices'][4]="Procesor"; 
$LANG['devices'][5]="Płyta Główna"; 
$LANG['devices'][6]="Pamięć"; 
$LANG['devices'][7]="Karta Dźwiękowa"; 
$LANG['devices'][19]="Napędy"; 
$LANG['devices'][20]="Kontrolery"; 
$LANG['devices'][21]="Inne Peryferia"; 
$LANG['devices'][22]="Obudowy"; 
$LANG['devices'][23]="Zasilacz"; 
$LANG['devices'][24]="domyślnie"; 
$LANG['devices'][25]="Dodaj komponent"; 
$LANG['devices'][26]="Usuń komponent"; 

$LANG['device_case'][0]="Rozmiar"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Zapisywalny"; 
$LANG['device_drive'][1]="Prędkość"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Pojemność"; 

$LANG['device_iface'][0]="Przepływ"; 
$LANG['device_iface'][2]="Adres Mac"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Moc"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Częstotliwość"; 
$LANG['device_ram'][2]="Rozmiar"; 

$LANG['document'][1]="Suma kontrolna (SHA1)"; 
$LANG['document'][2]="Plik"; 
$LANG['document'][3]="Nagłówek"; 
$LANG['document'][4]="Typ MIME"; 
$LANG['document'][7]="Typy dokumentów"; 
$LANG['document'][9]="Rozszerzenie"; 
$LANG['document'][10]="Ikona"; 
$LANG['document'][11]="Autoryzowane pobieranie"; 
$LANG['document'][15]="Pobieranie"; 
$LANG['document'][16]="Dodaj Dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Połączone pozycje"; 
$LANG['document'][21]="Połączone dokumenty"; 
$LANG['document'][22]="Aktualny Plik"; 
$LANG['document'][23]="Plik za duży, aby dodać."; 
$LANG['document'][24]="Kasowanie pliku zakończone"; 
$LANG['document'][25]="Nie można usunąć pliku"; 
$LANG['document'][26]="Ten plik jest poprawny. Wgrywanie zakończone."; 
$LANG['document'][27]="Nieudany zapis pliku."; 
$LANG['document'][28]="Brak pliku."; 
$LANG['document'][29]="Nie można utworzyć katalogu"; 
$LANG['document'][30]="Sprawdź czy masz poprawne prawa"; 
$LANG['document'][31]="Katalog dla dokumentów nie istnieje"; 
$LANG['document'][32]="Nieautoryzowany typ pliku"; 
$LANG['document'][33]="Link www"; 
$LANG['document'][34]="Utwórz katalog"; 
$LANG['document'][35]="Katalog do wgrania nie istnieje"; 
$LANG['document'][36]="Użyj pliku z zasobu FTP"; 
$LANG['document'][37]="Plik niedostępny"; 
$LANG['document'][38]="Pliku nie znaleziono"; 
$LANG['document'][39]="Dokument pomyślnie przeniesiono"; 
$LANG['document'][40]="Przeniesienie pliku nieudane"; 
$LANG['document'][41]="Dokument pomyślnie skopiowano"; 
$LANG['document'][42]="Dodane przez"; 
$LANG['document'][43]="Plik nieznany"; 
$LANG['document'][44]="Błędna nazwa pliku"; 
$LANG['document'][45]="Nieautoryzowany dostęp do pliku"; 
$LANG['document'][46]="Błąd podczas wysyłania pliku (możliwe że za duży)"; 
$LANG['document'][48]="Dokument z tym plikiem już istnieje"; 
$LANG['document'][49]="plik został zmieniony (zła suma kontrolna)"; 
$LANG['document'][50]="Dołączone pozycje"; 

$LANG['entity'][0]="Oddział"; 
$LANG['entity'][2]="Nadrzędna jednostka"; 
$LANG['entity'][3]="Połącz z obiektem"; 
$LANG['entity'][5]="Automatyczne przypisanie komputerów"; 
$LANG['entity'][6]="Automatyczne przydzielanie użytkowników"; 
$LANG['entity'][7]="drzewo struktury"; 
$LANG['entity'][8]="Po oddziale"; 
$LANG['entity'][9]="Oddział podrzędny"; 
$LANG['entity'][10]="Wybierz żądany oddział"; 
$LANG['entity'][11]="Zobacz oddziały i ich pododdziały"; 
$LANG['entity'][12]="Atrybut LDAP identyfikujący oddział"; 
$LANG['entity'][13]="Tag identyfikujący oddział"; 
$LANG['entity'][14]="Zaawansowane informacje"; 
$LANG['entity'][15]="Jednostki katalogu LDAP"; 
$LANG['entity'][16]="Filtr przeszukiwania (jeżeli potrzebny)"; 
$LANG['entity'][17]="Automatyczne zamykanie konfiguracji"; 
$LANG['entity'][18]="Automatyczne zamknięcie zgłoszenia po"; 

$LANG['event'][0]="Źródło"; 
$LANG['event'][2]="Serwis"; 
$LANG['event'][3]="Poziom"; 
$LANG['event'][4]="Wiadomość"; 
$LANG['event'][18]="Pole"; 
$LANG['event'][19]="Uaktualnij"; 
$LANG['event'][20]="Brak historii"; 

$LANG['financial'][1]="Umowa"; 
$LANG['financial'][2]="Życie"; 
$LANG['financial'][3]="Informacje finansowe"; 
$LANG['financial'][4]="Numer"; 
$LANG['financial'][5]="Koszt"; 
$LANG['financial'][6]="Typ umowy"; 
$LANG['financial'][8]="Czas trwania"; 
$LANG['financial'][9]="lata"; 
$LANG['financial'][10]="Ostrzeżenie"; 
$LANG['financial'][11]="Faktura okresowa"; 
$LANG['financial'][13]="Numer zaksięgowania"; 
$LANG['financial'][14]="Zakup"; 
$LANG['financial'][15]="Okres gwarancji"; 
$LANG['financial'][16]="Informacje gwarancyjne"; 
$LANG['financial'][18]="Numer zamówienia"; 
$LANG['financial'][19]="Dostawa z"; 
$LANG['financial'][20]="Numer unieruchomienia"; 
$LANG['financial'][21]="Wartość"; 
$LANG['financial'][22]="Typ amortyzacji"; 
$LANG['financial'][23]="Okres trwania amortyzacji"; 
$LANG['financial'][24]="Dodaj kontakt"; 
$LANG['financial'][25]="Dodaj dostawcę"; 
$LANG['financial'][26]="Dostawca"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Dodaj Kontakt"; 
$LANG['financial'][36]="Dodaj Umowę"; 
$LANG['financial'][42]="Komercyjne"; 
$LANG['financial'][43]="Technik"; 
$LANG['financial'][44]="Adres"; 
$LANG['financial'][45]="Strona www"; 
$LANG['financial'][46]="Skojarzone kontakty"; 
$LANG['financial'][47]="Liniowy"; 
$LANG['financial'][48]="Czas trwania"; 
$LANG['financial'][50]="Wypożyczenia"; 
$LANG['financial'][51]="Wynajmowanie"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Ubezpieczenie"; 
$LANG['financial'][54]="Pomoc Sprzętowa"; 
$LANG['financial'][55]="Pomoc Software"; 
$LANG['financial'][56]="Usługę dostarczał"; 
$LANG['financial'][57]="miesiąc"; 
$LANG['financial'][59]="Godziny interwencji"; 
$LANG['financial'][60]="w tygodniu"; 
$LANG['financial'][61]="w Soboty"; 
$LANG['financial'][62]="Niedziele i święta"; 
$LANG['financial'][65]="Skojarzeni dostawcy"; 
$LANG['financial'][66]="Skojarzone umowy"; 
$LANG['financial'][68]="Aktywuj informacje finansowe"; 
$LANG['financial'][69]="Umowy okresowe"; 
$LANG['financial'][76]="Data rozpoczęcia"; 
$LANG['financial'][77]="Współczynnik amortyzacji"; 
$LANG['financial'][78]="Koniec gwarancji"; 
$LANG['financial'][79]="Inne typy"; 
$LANG['financial'][80]="Koniec gwarancji"; 
$LANG['financial'][81]="Zaksięgowana wartość netto"; 
$LANG['financial'][82]="Numer faktury / rachunku"; 
$LANG['financial'][83]="Maksymalna liczba pozycji"; 
$LANG['financial'][84]="Informacje finansowe będą dostępne tylko jeżeli je dodasz."; 
$LANG['financial'][85]="Poszukiwana pozycja nieznaleziona"; 
$LANG['financial'][86]="Zakończenie kontraktu"; 
$LANG['financial'][87]="Budżet"; 
$LANG['financial'][88]="Wygasa:"; 
$LANG['financial'][89]="TCO (cena + koszt śledzenia)"; 
$LANG['financial'][90]="Miesięczny"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Wygasające umowy - ostatnie 30 dni"; 
$LANG['financial'][94]="Wygasające umowy w mniej niż 7 dni"; 
$LANG['financial'][95]="Wygasające umowy w mniej niż 30 dni"; 
$LANG['financial'][96]="Umowy które będą alarmowane w mniej niż 7 dni"; 
$LANG['financial'][97]="Umowy które będą alarmowane w mniej niż 30 dni"; 
$LANG['financial'][98]="Data koncowa"; 
$LANG['financial'][99]="Data Końcowa + Ostrzeżenie"; 
$LANG['financial'][100]="Kod pocztowy"; 
$LANG['financial'][101]="Miasto"; 
$LANG['financial'][102]="Województwo"; 
$LANG['financial'][103]="Kraj"; 
$LANG['financial'][104]="Powiązane elementy"; 
$LANG['financial'][105]="Cichy"; 
$LANG['financial'][106]="Ekspres"; 
$LANG['financial'][107]="Odnowienie"; 
$LANG['financial'][108]="W sumie wydane w budżecie"; 
$LANG['financial'][109]="Pozostało w budżecie"; 
$LANG['financial'][110]="budżet"; 

$LANG['gmt'][0]="Średni Czas Zachodnioeuropejski"; 
$LANG['gmt'][1]="godzina(ny)"; 
$LANG['gmt'][2]="godz."; 

$LANG['help'][1]="Tabela kalkulacji i priorytetów"; 
$LANG['help'][2]="ważny"; 
$LANG['help'][3]="Bardzo Wysoki"; 
$LANG['help'][4]="Wysoki"; 
$LANG['help'][5]="Średni"; 
$LANG['help'][6]="Niski"; 
$LANG['help'][7]="Bardzo Niski"; 
$LANG['help'][8]="Informuj mnie o podjętych czynnościach"; 
$LANG['help'][11]="Mój e-mail"; 
$LANG['help'][14]="Wyślij Wiadomość"; 
$LANG['help'][16]="Jeśli chcesz być informowany o podjętych działaniach, musisz podać Twój adres e-mail!"; 
$LANG['help'][18]="Wiadomość została wysłana poprawnie, Twoje zgłoszenie zostanie sprawdzone."; 
$LANG['help'][19]="Dziękujemy za użycie systemu pomocy Helpdesk."; 
$LANG['help'][22]="Szukaj ID Twojego komputera"; 
$LANG['help'][23]="Wpisz pierwsze litery (nazwy użytkownika, pozycji lub numeru seryjnego)"; 
$LANG['help'][24]="Typ sprzętu"; 
$LANG['help'][25]="Komputer"; 
$LANG['help'][26]="Urządzenie sieciowe"; 
$LANG['help'][27]="Drukarka"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Urządzenie"; 
$LANG['help'][30]="Ogólne"; 
$LANG['help'][31]="Oprogramowanie"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Brak tytułu w twoim bilecie, powtórz proszę."; 
$LANG['help'][41]="Brak kategorii w twoim bilecie, powtórz proszę."; 
$LANG['help'][42]="Bardzo wysoki"; 
$LANG['help'][43]="wysoki"; 
$LANG['help'][44]="Średni"; 
$LANG['help'][45]="Niski"; 
$LANG['help'][46]="Bardzo niski"; 
$LANG['help'][47]="Bardzo wysoki"; 
$LANG['help'][48]="wysoki"; 
$LANG['help'][49]="Średni"; 
$LANG['help'][50]="Niski"; 
$LANG['help'][51]="Bardzo niski"; 

$LANG['install'][0]="Instalowanie lub aktualizacja GLPI"; 
$LANG['install'][1]="Wybierz 'Instalacja' dla całkowicie nowej instalacji GLPI."; 
$LANG['install'][2]="Wybierz 'Aktualizacja' dla uaktualnienia GLPI ze starszej wersji"; 
$LANG['install'][3]="Instalacja"; 
$LANG['install'][4]="Aktualizacja"; 
$LANG['install'][5]="Sprawdzam kompatybilność twojego systemu do uruchomienia GLPI"; 
$LANG['install'][6]="Test wykonany"; 
$LANG['install'][7]="Wyniki"; 
$LANG['install'][8]="Testowanie parser'a PHP"; 
$LANG['install'][9]="Musisz zainstalować przynajmniej PHP5."; 
$LANG['install'][10]="GLPI nie jest kompatybilny z opcją: zend.ze1_compatibility_mode = On"; 
$LANG['install'][11]="Wersja PHP jest conajmniej 5.x - Idealnie !"; 
$LANG['install'][12]="Test sesji"; 
$LANG['install'][13]="Twój parser PHP nie ma wkompilowanej obsługi sesji !"; 
$LANG['install'][14]="Obsługa sesji dostępna - Idealnie !"; 
$LANG['install'][15]="Upewnij sie czy obługa sesji została aktywowana w php.ini"; 
$LANG['install'][16]="Sprawdzanie praw zapisu dla zrzutów danych"; 
$LANG['install'][17]="Plik nie może być utworzony."; 
$LANG['install'][18]="Nieoficjalne tłumaczenia są również dostępne"; 
$LANG['install'][19]="Plik został stworzony, ale nie może być usunięty."; 
$LANG['install'][20]="Plik został utworzony i skasowany - Idealnie!"; 
$LANG['install'][21]="Sprawdzanie praw zapisu dla dokumentów"; 
$LANG['install'][22]="Plik utworzono - Doskonale!"; 
$LANG['install'][23]="Sprawdzanie praw zapisu dla plików konfiguracyjnych"; 
$LANG['install'][24]="Inicjalizacja bazy danych"; 
$LANG['install'][25]="Dalej ?"; 
$LANG['install'][26]="Dalej"; 
$LANG['install'][27]="Sprubuj ponownie"; 
$LANG['install'][28]="Ustawaianie połączenia z bazą danych"; 
$LANG['install'][29]="Parametry połączenia z bazą danych"; 
$LANG['install'][30]="Serwer Mysql"; 
$LANG['install'][31]="Użytkownik Mysql"; 
$LANG['install'][32]="Hasło Mysql"; 
$LANG['install'][34]="Testowanie połączenia z bazą danych"; 
$LANG['install'][35]="Nie mogę połączyć sie z bazą danych"; 
$LANG['install'][36]="Serwer odpowiedział"; 
$LANG['install'][37]="Pole serwer i/lub użytkownik jest puste"; 
$LANG['install'][38]="Proszę wybrać baze danych"; 
$LANG['install'][39]="Stwórz nową bazę danych lub użyj istniejącej:"; 
$LANG['install'][40]="Prosze wybrać baze danych do aktualizacji:"; 
$LANG['install'][41]="Nie możliwe użycie bazy danych:"; 
$LANG['install'][43]="OK - baza danych zainicjowana"; 
$LANG['install'][47]="Niemożliwy zapis pliku konfiguracyjnego bazy danych"; 
$LANG['install'][48]="Błąd przy tworzeniu nowej bazy danych!"; 
$LANG['install'][49]="Nie wybrałeś bazy danych !"; 
$LANG['install'][50]="Sprawdzanie praw zapisu dla plików sesyjnych"; 
$LANG['install'][52]="Sprawdzanie praw zapisu dla plików akcji automatycznych"; 
$LANG['install'][53]="Test zapisu plików z logami"; 
$LANG['install'][55]="Instalacja zakończona"; 
$LANG['install'][57]="Domyślne nazwa użytkownika / hasło to:"; 
$LANG['install'][58]="glpi/glpi dla konta administratora"; 
$LANG['install'][59]="tech/tech dla kont techników"; 
$LANG['install'][60]="normalny/normalny dla normalnych kont"; 
$LANG['install'][61]="post-only/post-only konto tylko do pisania wiadomości"; 
$LANG['install'][62]="Możesz usunąć lub zmodyfikować te konta tak jak przed datą pierwszego wprowadzenia do bazy danych."; 
$LANG['install'][64]="Używaj GLPI"; 
$LANG['install'][65]="test rozszerzenia magic_quotes_sybase"; 
$LANG['install'][66]="GLPI nie działa z opcją magic_quotes_sybase; proszę wyłącz ją i spróbuj ponownie"; 
$LANG['install'][67]="Opcja magic_quotes_sybase nie jest aktywna na twoim serwerze - Idealnie!"; 
$LANG['install'][68]="Automatyczny start sesji testowej"; 
$LANG['install'][69]="session.auto_start jest aktywny. W celu dalszych informacji zobacz plik .htaccess w katalogu głównym GLPI."; 
$LANG['install'][70]="Nie mogę utworzyć pliku połączenia z bazą danych, prosze zweryfikuj prawa tego pliku"; 
$LANG['install'][71]="Test rozszerzeń MySQL."; 
$LANG['install'][72]="Musisz skompilować PHP z obsługą rozszerzeń MySQL"; 
$LANG['install'][73]="OK - funkcja mysql_query() istnieje - Idealnie !"; 
$LANG['install'][74]="Sprawdz czy Session_use_trans_sid jest używany"; 
$LANG['install'][75]="Musisz wyłączyć opcje Session_use_trans_id w php.ini"; 
$LANG['install'][76]="OK - sesje działaja (zadnych problemów z trans_id) - Idealnie !"; 
$LANG['install'][77]="Krok"; 
$LANG['install'][81]="Rozpoczynanie instalacji"; 
$LANG['install'][82]="Baza danych została utworzona"; 
$LANG['install'][85]="Funkcjonalność znaleziona - Idelanie !"; 
$LANG['install'][86]="Test przydzielanej pamięci"; 
$LANG['install'][87]="Przydzielonej pamięci:"; 
$LANG['install'][88]="Wymagana minimalna ilość pamięci dla GLPI to 64M"; 
$LANG['install'][89]="Idealnie !"; 
$LANG['install'][90]="Spróbuj zwiększyć parametr memory_limit w pliku php.ini."; 
$LANG['install'][91]="Przydzielonej pamięci > 64M"; 
$LANG['install'][92]="Licencja"; 
$LANG['install'][93]="Przeczytałem i AKCPTUJE wypisane powyżej warunki licencji."; 
$LANG['install'][94]="Przeczytałem i NIE AKCEPTUJE warunków licencji wpisanych powyżej."; 
$LANG['install'][95]="Nielimitowana pamięć"; 
$LANG['install'][96]="Nielimitowana pamięć"; 
$LANG['install'][97]="Sprawdz uprawnienia w katalogu:"; 
$LANG['install'][99]="Sprawdzanie praw dostępu do plików tymczasowych"; 
$LANG['install'][100]="Katalog nie może zostać utworzony"; 
$LANG['install'][101]="Katalog został stworzony ale nie moze zostać usunięty"; 
$LANG['install'][102]="Test funkcji: json"; 
$LANG['install'][103]="GLPI nie może pracować poprawnie bez funkcji: json_encode i json_decode"; 
$LANG['install'][104]="test rozszerzenia mbstring"; 
$LANG['install'][105]="Rozszerzenie Mbstring w parserze PHP nie jest zainstalowane"; 
$LANG['install'][106]="Sprawdzanie uprawnień zapisu dla plików graficznych"; 

$LANG['job'][2]="przez"; 
$LANG['job'][4]="Zgłaszający"; 
$LANG['job'][5]="Przypisany do"; 
$LANG['job'][6]="Technik"; 
$LANG['job'][7]="Zadanie"; 
$LANG['job'][8]="ostatnie zgłoszenie"; 
$LANG['job'][9]="Śledzenia"; 
$LANG['job'][11]="Opisz problem lub wymagane działanie"; 
$LANG['job'][12]="Brak śledzenia dla tego zgłoszenia"; 
$LANG['job'][13]="Nowe zgloszenie"; 
$LANG['job'][15]="Rozwiązane"; 
$LANG['job'][19]="Wysyłaj e-mailem śledzenia"; 
$LANG['job'][20]="Sumaryczny czas trwania"; 
$LANG['job'][21]="godzin(y)"; 
$LANG['job'][22]="minut"; 
$LANG['job'][29]="Dodaj nowe śledzenie"; 
$LANG['job'][30]="Dodaj nowe zadanie"; 
$LANG['job'][31]="Czas trwania"; 
$LANG['job'][32]="Nic"; 
$LANG['job'][33]="Pusty Czas Trwania"; 
$LANG['job'][34]="Planuj to zadanie"; 
$LANG['job'][35]="Planowanie"; 
$LANG['job'][37]="Podsumowanie"; 
$LANG['job'][38]="Zgłoszenie"; 
$LANG['job'][39]="Uaktualnij śledzenie"; 
$LANG['job'][40]="Koszt czasu"; 
$LANG['job'][41]="Koszt stały"; 
$LANG['job'][42]="Koszt materiałów"; 
$LANG['job'][43]="Koszt całkowity"; 
$LANG['job'][44]="Źródło zgłoszenia"; 
$LANG['job'][45]="Źródło śledzenia"; 
$LANG['job'][46]="Zgłoszenie utworzone w oddziale"; 
$LANG['job'][47]="Koszty"; 
$LANG['job'][48]="Typ rozwiązania"; 
$LANG['job'][49]="Nowe zadanie"; 
$LANG['job'][50]="Brak zadania dla tego zlecenia"; 
$LANG['job'][51]="Zatwierdzenie rozwiązania"; 
$LANG['job'][52]="Uaktualnij zadanie"; 
$LANG['job'][53]="Usuwanie jako zadanie"; 
$LANG['job'][54]="Bez odpowiedzi, zgłoszenie zostanie automatycznie zamknięte po"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Poszukuj tylko raz"; 
$LANG['joblist'][2]="Priorytet"; 
$LANG['joblist'][3]="Osobiste + grupy"; 
$LANG['joblist'][4]="Przydzielone"; 
$LANG['joblist'][6]="Opis"; 
$LANG['joblist'][7]="Nowe zgłoszenie dla tego elementu"; 
$LANG['joblist'][8]="Brak zgloszeń"; 
$LANG['joblist'][9]="Nowy"; 
$LANG['joblist'][10]="Zamknięte (rozwiązane)"; 
$LANG['joblist'][11]="Otwarte"; 
$LANG['joblist'][12]="Zamknięte o"; 
$LANG['joblist'][13]="Zgłoszenia do przetworzenia"; 
$LANG['joblist'][14]="Rozwiązywanie włączone"; 
$LANG['joblist'][16]="Brak zgłoszeń w toku"; 
$LANG['joblist'][17]="Zamknięte (nie rozwiązane)"; 
$LANG['joblist'][18]="W toku (przypisane)"; 
$LANG['joblist'][19]="W toku (zaplanowane)"; 
$LANG['joblist'][21]="W toku"; 
$LANG['joblist'][26]="Trwające"; 
$LANG['joblist'][27]="E-mail dla śledzenia"; 
$LANG['joblist'][28]="Zgłoszenia z połączonymi pozycjami"; 
$LANG['joblist'][29]="Pilny"; 
$LANG['joblist'][30]="Zdarzenie"; 
$LANG['joblist'][32]="Rozwiązane"; 
$LANG['joblist'][33]="Zamknięte"; 
$LANG['joblist'][34]="Nie rozwiązany"; 
$LANG['joblist'][35]="Nie zamknięty"; 
$LANG['joblist'][36]="Wpis statusu w bazie danych"; 

$LANG['jobresolution'][1]="Rozwiązanie"; 
$LANG['jobresolution'][3]="Zatwierdzone rozwiązania"; 
$LANG['jobresolution'][4]="Odrzucone rozwiązanie"; 
$LANG['jobresolution'][5]="Jeżeli odrzucasz rozwiązanie, musisz podać powód"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Umieść tą pozycję w FAQ"; 
$LANG['knowbase'][6]="Wybierz kategorię dla tej pozycji"; 
$LANG['knowbase'][7]="Usuń tą pozycję z FAQ"; 
$LANG['knowbase'][8]="Edytuj tą pozycję"; 
$LANG['knowbase'][9]="Usuń tą pozycję"; 
$LANG['knowbase'][10]="Ta pozycja jest częścią FAQ"; 
$LANG['knowbase'][11]="Ta pozycja nie jest częścią FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Nazwa kategorii"; 
$LANG['knowbase'][14]="Temat"; 
$LANG['knowbase'][15]="Zawartość"; 
$LANG['knowbase'][24]="Dostęp do FAQ"; 
$LANG['knowbase'][26]="Widoki"; 
$LANG['knowbase'][27]="Włączony"; 
$LANG['knowbase'][29]="Ostatnie wprowadzenia"; 
$LANG['knowbase'][30]="Najbardziej popularne pytania"; 

$LANG['ldap'][0]="Masowy import użytkowników z katalogu LDAP"; 
$LANG['ldap'][1]="Synchronizuj importowanych użytkowników"; 
$LANG['ldap'][2]="Importuj nowych użytkowników"; 
$LANG['ldap'][3]="Brak użytkowników do importu"; 
$LANG['ldap'][4]="Wybór katalogu LDAP"; 
$LANG['ldap'][5]="Wybierz katalog LDAP do importu użytkowników"; 
$LANG['ldap'][6]="Nieudane połączenie z katalogiem LDAP"; 
$LANG['ldap'][7]="Brak katalogu LDAP zdefiniowanego w GLPI"; 
$LANG['ldap'][8]="Uwaga: Zapytania przekracza limit katalogu. Wyniki mogą być częściowe."; 
$LANG['ldap'][9]="Testowanie połączenia z katalogiem LDAP"; 
$LANG['ldap'][12]="Synchronizacja"; 
$LANG['ldap'][13]="w LDAP"; 
$LANG['ldap'][14]="w GLPI"; 
$LANG['ldap'][15]="Synchronizuj"; 
$LANG['ldap'][16]="Ponowna konfiguracja"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="Lista replik LDAP"; 
$LANG['ldap'][19]="Replika"; 
$LANG['ldap'][20]="dodaj replikę LDAP"; 
$LANG['ldap'][21]="Serwer główny"; 
$LANG['ldap'][22]="Replika(i)"; 
$LANG['ldap'][23]="Masowy import grup z katalogu LDAP"; 
$LANG['ldap'][24]="Import nowych grup"; 
$LANG['ldap'][25]="Żadna grupa nie została zaimportowana"; 
$LANG['ldap'][30]="Sposób w jaki LDAP powinno być połączone"; 
$LANG['ldap'][31]="Nigdy nie porównywane (domyślnie)"; 
$LANG['ldap'][32]="Zawsze porównywane"; 
$LANG['ldap'][33]="Różnice podczas przeszukiwania (ale nie zlokalizowane)"; 
$LANG['ldap'][34]="Różnice podczas lokalizowania (nie podczas przeszukiwania)"; 
$LANG['ldap'][35]="Import użytkownika"; 
$LANG['ldap'][36]="Brak katalogu przypisanego do oddziału: wyszukiwanie niemożliwe"; 
$LANG['ldap'][38]="Kryteria wyszukiwania użytkowników"; 
$LANG['ldap'][39]="Zaawansowany"; 
$LANG['ldap'][40]="Proste"; 
$LANG['ldap'][41]="Do zmiany"; 
$LANG['ldap'][42]="Nie wybrano katalogu"; 
$LANG['ldap'][43]="Brak użytkowników do synchronizacji"; 
$LANG['ldap'][44]="Domyślny serwer"; 
$LANG['ldap'][45]="Akcja wykonywana gdy użytkownika usunięto z LDAP"; 
$LANG['ldap'][46]="Z rysowaniem zależności pozwoleń i grup (dynamicznie)"; 
$LANG['ldap'][47]="Do kosza"; 
$LANG['ldap'][48]="Usunięci użytkownicy z LDAP"; 
$LANG['ldap'][49]="Zobacz użytkowników dodanych przed"; 
$LANG['ldap'][50]="Zobacz użytkowników uaktualnionych przed"; 
$LANG['ldap'][52]="Mniej niż"; 
$LANG['ldap'][53]="Więcej niż"; 
$LANG['ldap'][54]="Włącz filtrowanie po dacie."; 
$LANG['ldap'][55]="Wyłącz filtrowanie po dacie"; 
$LANG['ldap'][56]="Tygodnie"; 

$LANG['links'][1]="Link albo nazwa pliku"; 
$LANG['links'][4]="Typ sprzętu powiązanego"; 
$LANG['links'][6]="Poprawne tagi"; 
$LANG['links'][7]="Brak zdefiniowanego linku"; 
$LANG['links'][9]="Zawartość pliku"; 

$LANG['log'][1]="system"; 
$LANG['log'][16]="planowanie"; 
$LANG['log'][18]="komponenty"; 
$LANG['log'][20]="element dodany"; 
$LANG['log'][21]="odśwież pozycje"; 
$LANG['log'][22]="usuń pozycje"; 
$LANG['log'][23]="przywróc pozycje"; 
$LANG['log'][24]="wyczyść pozycje"; 
$LANG['log'][26]="odłącz pozycje"; 
$LANG['log'][27]="połączenia pozycji"; 
$LANG['log'][28]="update komponentów"; 
$LANG['log'][29]="zatwierdzenie/odrzucenie rozwiązania"; 
$LANG['log'][30]="skojarz z typem"; 
$LANG['log'][31]="usuń typ"; 
$LANG['log'][32]="dodaj link z pozycją"; 
$LANG['log'][33]="usuń link do pozycji"; 
$LANG['log'][34]="dodaj link z dostawcą"; 
$LANG['log'][35]="usuń link do dostawcy"; 
$LANG['log'][40]="Połączenia IP"; 
$LANG['log'][41]="Połączenie nieudane"; 
$LANG['log'][42]="Rezerwacja"; 
$LANG['log'][44]="Nagłówek"; 
$LANG['log'][45]="Powodzenie"; 
$LANG['log'][46]="Niepowodzenie"; 
$LANG['log'][48]="dodaj użytkownika do grupy"; 
$LANG['log'][49]="usuń użytkownika z grupy"; 
$LANG['log'][55]="Połączenie"; 
$LANG['log'][59]="Akcje automatyczne"; 
$LANG['log'][60]="odglobalizuj"; 
$LANG['log'][61]="dodaj użytkownika do jednostki"; 
$LANG['log'][62]="kompletnie usuń tego użytkownika"; 
$LANG['log'][64]="zmiana pola"; 
$LANG['log'][65]="rola"; 
$LANG['log'][66]="Bezpieczeństwo"; 
$LANG['log'][67]="zmień notatkę"; 
$LANG['log'][70]="dodano port sieciowy"; 
$LANG['log'][71]="Dodano porty sieciowe"; 
$LANG['log'][73]="usunięty port sieciowy"; 
$LANG['log'][74]="usunięto porty sieciowe"; 
$LANG['log'][75]="przesunięty port sieciowy"; 
$LANG['log'][77]="Przydziel VLAN do portu sieciowego"; 
$LANG['log'][78]="przydziel VLAN do kilku portów"; 
$LANG['log'][79]="Usunięto VLAN z portu sieciowego"; 
$LANG['log'][80]="rozłącz VLAN z portów sieciowych"; 
$LANG['log'][82]="dodawanie wersji"; 
$LANG['log'][83]="modyfikacja wersji"; 
$LANG['log'][84]="wersja usunięta"; 
$LANG['log'][85]="dodawanie licencji"; 
$LANG['log'][86]="modyfikacja licencji"; 
$LANG['log'][87]="licencja usunięta"; 
$LANG['log'][88]="dodawanie kartlidzy"; 
$LANG['log'][89]="dodawanie materiałów eksploatacyjnych"; 
$LANG['log'][90]="Wyłączenia kartlidzy"; 
$LANG['log'][91]="wyłączenia z materiałów"; 
$LANG['log'][92]="odzyskiwanie kartlidza"; 
$LANG['log'][93]="odzyskiwanie materiałów"; 
$LANG['log'][94]="Uaktualnienie kartlidza"; 
$LANG['log'][95]="Instalacja kartlidza"; 
$LANG['log'][96]="Odinstalowanie kartlidza"; 
$LANG['log'][97]="Materiały poza dostępnością użytkownika"; 
$LANG['log'][98]="dodaje pozycje"; 
$LANG['log'][99]="modyfikacja pozycji"; 
$LANG['log'][100]="usuwanie jako pozycja"; 

$LANG['login'][0]="Ostatnie logowanie"; 
$LANG['login'][1]="Spróbuj jeszcze raz"; 
$LANG['login'][2]="Katalog LDAP"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Dostęp zabroniony"; 
$LANG['login'][6]="Użytkownik"; 
$LANG['login'][7]="Hasło"; 
$LANG['login'][8]="Pusty login lub hasło"; 
$LANG['login'][9]="Jeszcze nie autoryzowano"; 
$LANG['login'][10]="Logowanie"; 
$LANG['login'][11]="Użytkownikowi odmówiono dostępu do GLPI"; 
$LANG['login'][12]="Zły login lub hasło"; 
$LANG['login'][13]="Nie wpisano hasła"; 
$LANG['login'][14]="Nieznany użytkownik"; 
$LANG['login'][15]="Użytkownik nie znaleziony lub kilku użytkowników nieznalezionych"; 
$LANG['login'][16]="Nieudana autoryzacja w LDAP"; 
$LANG['login'][18]="Bazowe wewnętrzne GLPI"; 
$LANG['login'][20]="Nie posiadasz dostępu do tej aplikacji ponieważ twoje konto zostało zdezaktywowane lub usunięte."; 
$LANG['login'][21]="Test połączenia z serwerem IMAP/POP"; 
$LANG['login'][22]="Test przeszedł pomyślnie"; 
$LANG['login'][23]="Test nieudany"; 
$LANG['login'][24]="Data ostatniego logowania"; 
$LANG['login'][25]="Nie jesteś uprawniony do połączenia"; 
$LANG['login'][26]="Do prawidłowej obsługi musisz włączyć JavaScript w swojej przeglądarce"; 
$LANG['login'][27]="Do prawidłowego używania tej strony musisz włączyć akceptacje plików cookies"; 
$LANG['login'][30]="Zmień metodę uwierzytelniania"; 
$LANG['login'][31]="Uwierzytelnianie w katalogu LDAP"; 
$LANG['login'][32]="Uwierzytelnianie w bazie GLPI"; 
$LANG['login'][33]="Uwierzytelnianie w serwerze IMAP/POP"; 

$LANG['mailgate'][0]="Odbiorca email"; 
$LANG['mailgate'][2]="Pobierz zgłoszenia e-mail"; 
$LANG['mailgate'][3]="Liczba dostępnych i odzyskanych e-maili"; 
$LANG['mailgate'][4]="nie znaleziono  rozszerzenia mbstring. Ostrzeżenia użyły charsets."; 
$LANG['mailgate'][5]="Dołączony plik jest niepoprawny"; 
$LANG['mailgate'][6]="Za duży plik załącznika"; 
$LANG['mailgate'][7]="Maksymalny rozmiar pliku załącznika dla odbiorcy email"; 
$LANG['mailgate'][9]="Twoja wiadomość nie może zostać sprawdzona. \n jeżeli problem się powtarza skontaktuj się z administratorem"; 
$LANG['mailgate'][10]="Wiadomość odrzucona"; 
$LANG['mailgate'][11]="Trwa import emaili"; 
$LANG['mailgate'][12]="Nieudany wpływ email na oddział"; 
$LANG['mailgate'][13]="Powód niepowodzenia"; 
$LANG['mailgate'][14]="Email nie znaleziony. Import niemożliwy."; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="-----------------------"; 
$LANG['mailing'][1]="======================================="; 
$LANG['mailing'][4]="Zakończone śledzenia"; 
$LANG['mailing'][5]="Opis zgłoszenia"; 
$LANG['mailing'][10]="Nowe śledzenie zgłoszeń"; 
$LANG['mailing'][12]="Zgłoszenie przydzielone do"; 
$LANG['mailing'][14]="Aktualizacja kategorii zgłoszenia"; 
$LANG['mailing'][15]="Aktualizacja priorytetu dla zgłoszenia"; 
$LANG['mailing'][17]="Aktualizacja pozycji zgłoszenia"; 
$LANG['mailing'][18]="Aktualizacja autora zgłoszenia"; 
$LANG['mailing'][19]="Nowa rezerwacja"; 
$LANG['mailing'][20]="Aktualizacja grupy zgłoszenia"; 
$LANG['mailing'][21]="Zmień źródło zgłoszenia"; 
$LANG['mailing'][23]="Modyfikacja rezerwacji"; 
$LANG['mailing'][26]="Dodane dokumenty:"; 
$LANG['mailing'][27]="Aktualizacja statusu zgłoszenia"; 
$LANG['mailing'][29]="Rezerwacja została anulowana"; 
$LANG['mailing'][30]="Zgłoszenie zostało uaktualnione"; 
$LANG['mailing'][31]="To jest testowy mail aby sprawdzić czy system mailowy działa"; 
$LANG['mailing'][32]="Test e-mail"; 
$LANG['mailing'][33]="Alarm kartridży"; 
$LANG['mailing'][35]="Próg alarmów dla typów zużytych:"; 
$LANG['mailing'][36]="Alarmy zużycia"; 
$LANG['mailing'][37]="Umowa wprowadzona w czasie ostrzeżenia:"; 
$LANG['mailing'][39]="Alarm umowy"; 
$LANG['mailing'][40]="Pozycja z końcem gwarancji:"; 
$LANG['mailing'][41]="Alarmy finansowe"; 
$LANG['mailing'][42]="Zmień koszt czasu"; 
$LANG['mailing'][43]="Zmień koszt stały"; 
$LANG['mailing'][44]="Zmień koszt materiałów"; 
$LANG['mailing'][45]="Zmień tytuł zgłoszenia"; 
$LANG['mailing'][46]="Zmień opis zgłoszenia"; 
$LANG['mailing'][47]="Błąd podczas przesyłania e-maila"; 
$LANG['mailing'][48]="Zmiana w dacie otwarcia"; 
$LANG['mailing'][49]="Zmień datę zamknięcia"; 
$LANG['mailing'][50]="Zmień odbiorcę zgłoszenia"; 
$LANG['mailing'][51]="Wygaśnięte licencje:"; 
$LANG['mailing'][53]="Zmień rozwiązanie"; 
$LANG['mailing'][54]="Data wygaśnięcia"; 
$LANG['mailing'][100]="Nie zdefiniowano kategorii"; 
$LANG['mailing'][101]="Śledzenie e-mail zostało włączone"; 
$LANG['mailing'][102]="Śledzenie e-mail zostało wyłączone"; 
$LANG['mailing'][104]="Trwanie Śledzenia"; 
$LANG['mailing'][105]="Nie przydzielony"; 
$LANG['mailing'][107]="Nic"; 
$LANG['mailing'][109]="brak grupy"; 
$LANG['mailing'][110]="Niepoprawny e-mail"; 
$LANG['mailing'][113]="Szablon powiadomień"; 
$LANG['mailing'][114]="Ciało"; 
$LANG['mailing'][115]="Główna cześć email-a"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="tekst"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Zdarzenie"; 
$LANG['mailing'][120]="Metoda powiadomienia"; 
$LANG['mailing'][121]="Odbiorcy"; 
$LANG['mailing'][122]="Ukończone zadanie/a"; 
$LANG['mailing'][123]="Rozwiązano zgłoszenie"; 
$LANG['mailing'][124]="Dodaj nowe tłumaczenie"; 
$LANG['mailing'][125]="Domyślne tłumaczenie"; 
$LANG['mailing'][126]="Wzór tłumaczenia"; 
$LANG['mailing'][127]="Zamykanie zgłoszenia"; 
$LANG['mailing'][128]="zostaw te pole puste dla wygenerowanie z HTML"; 
$LANG['mailing'][129]="Usuwanie jako zgłoszenie"; 
$LANG['mailing'][130]="Od"; 
$LANG['mailing'][131]="Odbiorca"; 
$LANG['mailing'][132]="Nagłówek wiadomości"; 
$LANG['mailing'][133]="Usuń email(e)"; 
$LANG['mailing'][134]="Uaktualnienie śledzenia"; 
$LANG['mailing'][135]="śledzenie usuwania"; 
$LANG['mailing'][136]="Koniec rezerwacji"; 
$LANG['mailing'][137]="Użytkownik sprzętu"; 
$LANG['mailing'][138]="Lista dostępnych tagów"; 
$LANG['mailing'][139]="Etykieta"; 
$LANG['mailing'][140]="TAG"; 
$LANG['mailing'][141]="Śledzenia"; 
$LANG['mailing'][142]="Zadania"; 
$LANG['mailing'][143]="Sprawdzanie"; 
$LANG['mailing'][144]="Historyczny"; 
$LANG['mailing'][145]="Lista wartości"; 
$LANG['mailing'][146]="Pojedyncza wartość"; 
$LANG['mailing'][147]="Możliwe wartości"; 

$LANG['Menu'][0]="Komputery"; 
$LANG['Menu'][1]="Urz. Sieciowe"; 
$LANG['Menu'][2]="Drukarki"; 
$LANG['Menu'][3]="Monitory"; 
$LANG['Menu'][4]="Oprogramowanie"; 
$LANG['Menu'][5]="Zgłoszenia"; 
$LANG['Menu'][6]="Raporty"; 
$LANG['Menu'][11]="Ustawienia"; 
$LANG['Menu'][12]="Utrzymanie"; 
$LANG['Menu'][13]="Statystyki"; 
$LANG['Menu'][14]="Użytkownicy"; 
$LANG['Menu'][15]="Administracja"; 
$LANG['Menu'][16]="Akcesoria"; 
$LANG['Menu'][17]="Rezerwacje"; 
$LANG['Menu'][18]="Narzędzia"; 
$LANG['Menu'][19]="Baza wiedzy"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Kartridże"; 
$LANG['Menu'][22]="Kontakty"; 
$LANG['Menu'][23]="Dostawcy"; 
$LANG['Menu'][24]="Informacje Handlowe"; 
$LANG['Menu'][25]="Umowy"; 
$LANG['Menu'][26]="Zarządzanie"; 
$LANG['Menu'][27]="Dokumenty"; 
$LANG['Menu'][28]="Status urządzeń"; 
$LANG['Menu'][29]="Planowanie"; 
$LANG['Menu'][30]="Logi"; 
$LANG['Menu'][31]="Środowisko uproszczone"; 
$LANG['Menu'][32]="Materiały eksploatacyjne"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefony"; 
$LANG['Menu'][35]="Profile"; 
$LANG['Menu'][36]="Grupy"; 
$LANG['Menu'][37]="Oddziały"; 
$LANG['Menu'][38]="Spis"; 
$LANG['Menu'][39]="Odbiorca e-mail"; 
$LANG['Menu'][40]="Zakładki"; 
$LANG['Menu'][41]="Uprawnienia"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Głośniki"; 
$LANG['monitors'][18]="Dodatki"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Rozmiar"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Port sieciowy"; 
$LANG['networking'][5]="Pamięć (MB)"; 
$LANG['networking'][6]="Port sieciowy"; 
$LANG['networking'][13]="znalezione porty sieciowe"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Podłączone do"; 
$LANG['networking'][19]="Dodaj port sieciowy"; 
$LANG['networking'][21]="Numer portu"; 
$LANG['networking'][25]="włącz"; 
$LANG['networking'][37]="Znaleziony port sieciowy"; 
$LANG['networking'][44]="Port"; 
$LANG['networking'][46]="Dodaj kilka portów sieciowych"; 
$LANG['networking'][47]="Z"; 
$LANG['networking'][48]="Do"; 
$LANG['networking'][51]="Punkt sieci"; 
$LANG['networking'][55]="Połącz z VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Wybierz MAC adres z listy lub wpisz poniżej"; 
$LANG['networking'][58]="Odłącz VLAN"; 
$LANG['networking'][59]="Brama"; 
$LANG['networking'][60]="Maska"; 
$LANG['networking'][61]="Podsieć"; 

$LANG['ocsconfig'][1]="Użytkownik bazy danych OCSweb"; 
$LANG['ocsconfig'][2]="Host z bazą OCSNG"; 
$LANG['ocsconfig'][3]="Hasło użytkownika OCS"; 
$LANG['ocsconfig'][4]="Nazwa bazy danych OCS"; 
$LANG['ocsconfig'][5]="Opcje Importu"; 
$LANG['ocsconfig'][6]="Ignoruj import OCSNG"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Wyłączenie podążających tagów (separator $, nic dla wszystkich)"; 
$LANG['ocsconfig'][10]="Import globalny"; 
$LANG['ocsconfig'][11]="brak importu"; 
$LANG['ocsconfig'][12]="Importowane jednostki"; 
$LANG['ocsconfig'][13]="Importowane jednostki: wszystko zostanie zaimportowane 'tak jak było'"; 
$LANG['ocsconfig'][14]="Import globalny: wszystko zostanie zaimportowane ale materiał będzie zarządzany globalnie (jako jeden wpis z wieloma polaczeniami czy elementami)"; 
$LANG['ocsconfig'][15]="Brak importu: te elementy nie zostaną importowane"; 
$LANG['ocsconfig'][16]="Status domyślny"; 
$LANG['ocsconfig'][17]="Limit importu podążających tagów (separator $, nic dla wszystkich)"; 
$LANG['ocsconfig'][18]="Najpierw sprawdź duplikaty zarządzane w OCSNG"; 
$LANG['ocsconfig'][19]="Importowanie pozycji po numerze seryjnym"; 
$LANG['ocsconfig'][27]="Informacje ogólne"; 
$LANG['ocsconfig'][36]="Modemy"; 
$LANG['ocsconfig'][37]="Porty"; 
$LANG['ocsconfig'][38]="Użyj słownika OCS dla oprogramowania"; 
$LANG['ocsconfig'][39]="OCS TAG"; 
$LANG['ocsconfig'][40]="Liczba komputerów synchronizowanych okresowo"; 
$LANG['ocsconfig'][41]="Rejestr"; 
$LANG['ocsconfig'][43]="Informacje Administracyjne OCS"; 
$LANG['ocsconfig'][48]="Zachowanie przy rozłączaniu"; 
$LANG['ocsconfig'][49]="Kosz"; 
$LANG['ocsconfig'][50]="Usunięcie"; 
$LANG['ocsconfig'][52]="Automatyczne połączenia z komputerami"; 
$LANG['ocsconfig'][53]="Aktywuj automatyczny link"; 
$LANG['ocsconfig'][54]="Istniejące kryteria komputera"; 
$LANG['ocsconfig'][55]="Znajdz komputer posiadający status"; 
$LANG['ocsconfig'][56]="pusty"; 
$LANG['ocsconfig'][57]="równy"; 
$LANG['ocsconfig'][58]="Połączenie automatycznie połączy komputer w GLPI z komputerem z OCS-a. Ta opcja używana jest w skrypcie synchronizacji oraz przy ręcznym uaktualnieniu."; 
$LANG['ocsconfig'][59]="Adres konsoli OCS"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Synchronizuj komputery poprzednio zaimportowane"; 
$LANG['ocsng'][2]="Importuj nowe komputery"; 
$LANG['ocsng'][3]="Wyczyść połączenia pomiędzy GLPI i OCS"; 
$LANG['ocsng'][4]="Połącz nowy komputer OCS z istniejącym komputerem GLPI"; 
$LANG['ocsng'][5]="Import nowych komputerów"; 
$LANG['ocsng'][6]="Auto update"; 
$LANG['ocsng'][7]="Importowano z OCSNG"; 
$LANG['ocsng'][8]="Import udany"; 
$LANG['ocsng'][9]="Brak nowych komputerów do importowania"; 
$LANG['ocsng'][10]="Komputer uaktualniony w OCS"; 
$LANG['ocsng'][11]="Uaktualnij komputery"; 
$LANG['ocsng'][12]="Brak nowych maszyn do aktualizacji"; 
$LANG['ocsng'][13]="Import danych do GLPI"; 
$LANG['ocsng'][14]="Ostatnia inwentaryzacja w OCS"; 
$LANG['ocsng'][15]="Brak zablokowanych pozycji"; 
$LANG['ocsng'][16]="Zablokowane Pola"; 
$LANG['ocsng'][18]="Udane połączanie do bazy OCS"; 
$LANG['ocsng'][19]="Poprawna wersja i konfiguracja OCS NG"; 
$LANG['ocsng'][20]="Niewłaściwa wersja OCS NG - potrzebna RC3"; 
$LANG['ocsng'][21]="Nieudane połączenie do bazy OSC NG"; 
$LANG['ocsng'][22]="Uwaga! Importowane dane zamienią istniejące dane (sprawdź swoją konfigurację)"; 
$LANG['ocsng'][23]="Niemożliwy import, komputer w GLPI jest wprowadzony jako element z OCS"; 
$LANG['ocsng'][24]="Wymuś synchronizacje"; 
$LANG['ocsng'][26]="Wybierz na serwerze OCS-a"; 
$LANG['ocsng'][27]="Nie zdefiniowano serwera OCS"; 
$LANG['ocsng'][29]="Serwer OCS"; 
$LANG['ocsng'][30]="Zablokowane monitory"; 
$LANG['ocsng'][32]="Zablokowane urządzenia"; 
$LANG['ocsng'][34]="Zablokowane drukarki"; 
$LANG['ocsng'][36]="Oddział docelowy"; 
$LANG['ocsng'][37]="Aktywuj do podglądu"; 
$LANG['ocsng'][38]="Wyłącz podgląd"; 
$LANG['ocsng'][40]="Pasuje do wzorca?"; 
$LANG['ocsng'][41]="Tryb importu podręcznika"; 
$LANG['ocsng'][42]="Niepoprawna konfiguracja OCSNG (TRACE_DELETED musi być aktywne)"; 
$LANG['ocsng'][43]="Dostęp do bazy OCS zabroniony (Potrzebny do zapisania w hardware.CHECKSUM)"; 
$LANG['ocsng'][44]="Dostę do bazy OCS zabroniony (Potrzebny do usunięcia tabeli deleted_equiv)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Usuniete w OCSNG"; 
$LANG['ocsng'][47]="Połączony z komputerem z OCS"; 
$LANG['ocsng'][48]="Zmieniło się OCS ID komputera"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Zablokowane IP"; 
$LANG['ocsng'][52]="Zablokowane oprogramowanie"; 
$LANG['ocsng'][54]="Oprogramowanie usunięte podczas synchronizacji z OCS"; 
$LANG['ocsng'][55]="Partycja zablokowana"; 
$LANG['ocsng'][57]="Interfejs OCS"; 

$LANG['pager'][1]="do"; 
$LANG['pager'][2]="od"; 
$LANG['pager'][3]="z"; 
$LANG['pager'][4]="Pokaż"; 
$LANG['pager'][5]="pozycji"; 

$LANG['peripherals'][18]="Rodzaj"; 
$LANG['peripherals'][31]="Globalne zarządzanie"; 
$LANG['peripherals'][32]="Zarządzanie jednostką"; 
$LANG['peripherals'][33]="Typ zarządzania"; 

$LANG['phones'][18]="Gatunek"; 
$LANG['phones'][36]="Zasilacz"; 
$LANG['phones'][38]="Dodatkowa klawiatura"; 
$LANG['phones'][39]="Głośnik"; 
$LANG['phones'][40]="Ilość lini"; 

$LANG['planning'][0]="Wybrany specjalista jest już przydzielony w podanym terminie."; 
$LANG['planning'][1]="Błąd we wprowdzonych datach. Data końcowa jest jest starsza od daty początkowej"; 
$LANG['planning'][5]="Dzień"; 
$LANG['planning'][6]="Tydzień"; 
$LANG['planning'][8]="Śledzenie"; 
$LANG['planning'][9]="Po"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Pobierz kalendarz w formacie Ical"; 
$LANG['planning'][13]="webcal:// Synchronizacja"; 
$LANG['planning'][14]="Miesiąc"; 
$LANG['planning'][15]="Twoje planowania"; 
$LANG['planning'][16]="Informacje"; 
$LANG['planning'][17]="Do zrobienia"; 
$LANG['planning'][18]="Zrobione"; 

$LANG['plugins'][0]="Lista wtyczek"; 
$LANG['plugins'][2]="Zainstalowany / nie skonfigurowany"; 
$LANG['plugins'][3]="Zainstalowany / nie aktywowany"; 
$LANG['plugins'][4]="Błąd / do usunięcia"; 
$LANG['plugins'][5]="Nie istniejąca funkcja"; 
$LANG['plugins'][6]="Do uaktualnienia"; 
$LANG['plugins'][7]="Nie zainstalowano wtyczek"; 
$LANG['plugins'][8]="Zobacz katalog wtyczek"; 
$LANG['plugins'][9]="Autorzy"; 
$LANG['plugins'][10]="Dodatek niekompatybilny z tą wersją GLPI"; 

$LANG['printers'][14]="Serial"; 
$LANG['printers'][15]="Równoległy"; 
$LANG['printers'][18]="Porty"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="WiFi"; 
$LANG['printers'][30]="Początkowy stan licznika stron"; 
$LANG['printers'][31]="Strony wydrukowane"; 

$LANG['profiles'][0]="Globalne prawa"; 
$LANG['profiles'][1]="Uprawnienia Jednostki"; 
$LANG['profiles'][2]="Profile interfejsów"; 
$LANG['profiles'][4]="Dodaj śledzenia do zgłoszeń w mojej grupie(ach)"; 
$LANG['profiles'][5]="Stwórz zgłoszenie"; 
$LANG['profiles'][6]="Dodaj śledzenie zgłoszeń (dla zgłaszającego)"; 
$LANG['profiles'][7]="Pokaż wszystkie zgłoszenia"; 
$LANG['profiles'][8]="Pokaż wszystkie śledzenia i zadania (publiczne i prywatne)"; 
$LANG['profiles'][9]="Pokaż zlecone zadania i publiczne"; 
$LANG['profiles'][10]="Czytaj"; 
$LANG['profiles'][11]="Wpisz"; 
$LANG['profiles'][12]="Brak Dostępu"; 
$LANG['profiles'][13]="Profil Domyślny"; 
$LANG['profiles'][14]="Skasuj zgłoszenie"; 
$LANG['profiles'][15]="Dodaj śledzenie wszystkich zgłoszeń"; 
$LANG['profiles'][16]="Obciążenie zgłoszenia"; 
$LANG['profiles'][17]="'Kradnij' zgłoszenie"; 
$LANG['profiles'][18]="Uaktualnij zgłoszenie"; 
$LANG['profiles'][19]="Przydziel zgłoszenie"; 
$LANG['profiles'][20]="Zobacz własne planowania"; 
$LANG['profiles'][21]="Pokaż wszystkie planowania"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Rezerwacja administracji"; 
$LANG['profiles'][24]="Uaktualnij hasło"; 
$LANG['profiles'][26]="Pokaż zgłoszenia utworzone w swojej grupie"; 
$LANG['profiles'][27]="Zobacz urządzenia w swojej grupie"; 
$LANG['profiles'][28]="Rekursywnie"; 
$LANG['profiles'][29]="Dynamiczny"; 
$LANG['profiles'][30]="Przejrzyj informacje OCSNG"; 
$LANG['profiles'][31]="Synchronizuj ręcznie z OCSNG"; 
$LANG['profiles'][32]="Zobacz zgłoszenia (swoje + grupy)"; 
$LANG['profiles'][33]="Nie znaleziono użytkownika"; 
$LANG['profiles'][34]="Legenda"; 
$LANG['profiles'][35]="Uaktualnij wszystkie śledzenia"; 
$LANG['profiles'][36]="Zobacz wykaz dla ludzi z mojej grupy"; 
$LANG['profiles'][37]="Domyślny oddział"; 
$LANG['profiles'][38]="Widoczność"; 
$LANG['profiles'][39]="Przydzielanie"; 
$LANG['profiles'][40]="Uaktualnij"; 
$LANG['profiles'][41]="Utworzenie"; 
$LANG['profiles'][42]="Połączenia"; 
$LANG['profiles'][43]="Metoda autentykacji i synchronizacji użytkowników"; 
$LANG['profiles'][44]="Zmień priorytet"; 
$LANG['profiles'][45]="Dodaj zadanie do wszystkich zgłoszeń"; 
$LANG['profiles'][46]="Edytuj wszystkie zadania"; 
$LANG['profiles'][47]="Dodaje użytkowników z obcego źródła"; 
$LANG['profiles'][48]="Stwórz żądanie sprawdzenia"; 
$LANG['profiles'][49]="Sprawdzanie zgłoszenia"; 

$LANG['registry'][1]="UL"; 
$LANG['registry'][2]="Ścieżka"; 
$LANG['registry'][3]="Klucz/wartość"; 
$LANG['registry'][4]="Znaleziono klucz(cze) rejestru"; 
$LANG['registry'][5]="Nie znaleziono klucza w rejestrze"; 
$LANG['registry'][6]="Nazwa OCS"; 

$LANG['reminder'][0]="Notatki prywatne"; 
$LANG['reminder'][1]="Notatki publiczne"; 
$LANG['reminder'][6]="Nowa notatka"; 
$LANG['reminder'][9]="Tekst"; 
$LANG['reminder'][12]="Dodaj do kalendarza"; 
$LANG['reminder'][15]="Bez Tytułu"; 
$LANG['reminder'][16]="Notes globalny"; 

$LANG['reports'][0]="Wybierz raport który chcesz wygenerować"; 
$LANG['reports'][4]="Lista sprzętu z umowami"; 
$LANG['reports'][11]="Sprzęt z umową"; 
$LANG['reports'][12]="Typ sprzętu"; 
$LANG['reports'][13]="Data(y)"; 
$LANG['reports'][15]="Pokaż raport"; 
$LANG['reports'][19]="Alternatywna nazwa użytkownika"; 
$LANG['reports'][26]="Raport domyślny"; 
$LANG['reports'][27]="Po umowach"; 
$LANG['reports'][28]="Raporty roczne"; 
$LANG['reports'][33]="Raport Sieciowy"; 
$LANG['reports'][36]="Podłączone urządzenia"; 
$LANG['reports'][37]="Odrzucone"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Po Lokalizacji"; 
$LANG['reports'][41]="Po sprzęcie"; 
$LANG['reports'][42]="Po odrzuconych"; 
$LANG['reports'][46]="porty sprzętowe"; 
$LANG['reports'][47]="porty urządzeń"; 
$LANG['reports'][49]="Raport urządzeń sieciowych"; 
$LANG['reports'][51]="Raport sieciowy wg odrzuconych"; 
$LANG['reports'][52]="przełącznik"; 
$LANG['reports'][54]="Raport sieciowy wg lokalizacji"; 
$LANG['reports'][57]="Lista Materiałów"; 
$LANG['reports'][58]="Raport materiałów wg lat"; 
$LANG['reports'][60]="termin otwarcia"; 
$LANG['reports'][61]="Data zamknięcia"; 
$LANG['reports'][62]="Informacje finansowe o sprzęcie"; 
$LANG['reports'][63]="Inne informacje finansowe (licencje, kartridże, materiały eksploatacyjne)"; 
$LANG['reports'][64]="Data ustanowienia"; 

$LANG['reservation'][1]="Pozycje możliwe do rezerwacji"; 
$LANG['reservation'][2]="Urządzenie tymczasowo niedostępne"; 
$LANG['reservation'][3]="Przerwij udostępnianie"; 
$LANG['reservation'][5]="Udostępnij"; 
$LANG['reservation'][6]="zabroń wypożyczania"; 
$LANG['reservation'][7]="Akceptuj wypożyczenia"; 
$LANG['reservation'][8]="Książka"; 
$LANG['reservation'][9]="Zaksięguj pozycje"; 
$LANG['reservation'][16]="Do"; 
$LANG['reservation'][17]="OD"; 
$LANG['reservation'][18]="Pożądana pozycja jest juz zarezerwowana w tym oknie czasowym"; 
$LANG['reservation'][20]="Wróć do planowania"; 
$LANG['reservation'][21]="Zobacz rezerwacje"; 
$LANG['reservation'][22]="Modyfikuj komentarz"; 
$LANG['reservation'][25]="Możliwy do wypożyczenia sprzęt"; 
$LANG['reservation'][27]="Okresowo"; 
$LANG['reservation'][28]="Po tygodniach"; 
$LANG['reservation'][29]="Po dniach"; 
$LANG['reservation'][30]="czas"; 
$LANG['reservation'][31]="Po"; 
$LANG['reservation'][35]="Przyszłe i obecne Rezerwacje"; 
$LANG['reservation'][36]="Wcześniejsze Rezerwacje"; 
$LANG['reservation'][37]="Bez Rezerwacji"; 
$LANG['reservation'][38]="Czy jesteś pewny że chcesz usunąć tą pozycje z listy wypożyczonych?"; 
$LANG['reservation'][39]="To spowoduje usunięcie wszystkich aktywnych rezerwacji."; 
$LANG['reservation'][40]="Rezerwacje materiału wygasają dzisiaj"; 

$LANG['rulesengine'][0]="jest"; 
$LANG['rulesengine'][1]="nie jest"; 
$LANG['rulesengine'][2]="zawartość"; 
$LANG['rulesengine'][3]="nie zawiera"; 
$LANG['rulesengine'][4]="startuje z"; 
$LANG['rulesengine'][5]="zakończone przez"; 
$LANG['rulesengine'][6]="Kryteria"; 
$LANG['rulesengine'][7]="Akcje"; 
$LANG['rulesengine'][8]="Zarządzanie regułami"; 
$LANG['rulesengine'][9]="Operator logiczny"; 
$LANG['rulesengine'][10]="Pozycja"; 
$LANG['rulesengine'][11]="Typ akcji"; 
$LANG['rulesengine'][12]="Pola"; 
$LANG['rulesengine'][13]="Wartość"; 
$LANG['rulesengine'][14]="Kondycja"; 
$LANG['rulesengine'][15]="Powód"; 
$LANG['rulesengine'][16]="Kryteria"; 
$LANG['rulesengine'][17]="Reguły"; 
$LANG['rulesengine'][18]="Reguły wpływające na komputer jako jednostkę"; 
$LANG['rulesengine'][19]="Oddzialy i zasady przydzielania reguł"; 
$LANG['rulesengine'][20]="Zastosowano zasady"; 
$LANG['rulesengine'][21]="Zasady dla pododziałów"; 
$LANG['rulesengine'][22]="Przypisz"; 
$LANG['rulesengine'][23]="Lokalne zasady"; 
$LANG['rulesengine'][24]="Typ reguł"; 
$LANG['rulesengine'][25]="Nazwa komputera"; 
$LANG['rulesengine'][26]="Sprawdzanie wyrażenia regularnego"; 
$LANG['rulesengine'][27]="Nie pasujące wyrażenie regularne"; 
$LANG['rulesengine'][28]="Biznesowe reguły dla zgłoszeń"; 
$LANG['rulesengine'][29]="Wyświetl reguły"; 
$LANG['rulesengine'][30]="Akcja"; 
$LANG['rulesengine'][33]="słownik listy rozwijalnej"; 
$LANG['rulesengine'][35]="Słownik oprogramowania"; 
$LANG['rulesengine'][36]="Słownik producentów"; 
$LANG['rulesengine'][37]="Reguły przydzielania kategorii dla oprogramowania"; 
$LANG['rulesengine'][38]="Ponowne obliczenie"; 
$LANG['rulesengine'][40]="kategoria"; 
$LANG['rulesengine'][41]="Walidacja"; 
$LANG['rulesengine'][42]="I"; 
$LANG['rulesengine'][43]="LUB"; 
$LANG['rulesengine'][45]="Przypisz wartość z wyrażeń regularnych"; 
$LANG['rulesengine'][46]="Przydzielony adres IP"; 
$LANG['rulesengine'][47]="Przydzielona nazwa + domena"; 
$LANG['rulesengine'][48]="Przydziel wyposażenie"; 
$LANG['rulesengine'][49]="Przydzielony adres MAC"; 
$LANG['rulesengine'][50]="Słownik modeli komputerów"; 
$LANG['rulesengine'][51]="Słownik modeli monitorów"; 
$LANG['rulesengine'][52]="Słownik modeli telefonów"; 
$LANG['rulesengine'][53]="Słownik modeli urządzeń peryferyjnych"; 
$LANG['rulesengine'][54]="Słownik modeli drukarek"; 
$LANG['rulesengine'][55]="Słownik modeli sieciowych"; 
$LANG['rulesengine'][56]="Modele"; 
$LANG['rulesengine'][60]="Słownik typów komputerów"; 
$LANG['rulesengine'][61]="Monitory słownik typów"; 
$LANG['rulesengine'][62]="Słownik typów telefonów"; 
$LANG['rulesengine'][63]="Słownik typów urządzeń peryferyjnych"; 
$LANG['rulesengine'][64]="Drukarka słownik typów"; 
$LANG['rulesengine'][65]="Słownik typów urządzeń sieciowych"; 
$LANG['rulesengine'][66]="Typy"; 
$LANG['rulesengine'][67]="Słownik systemów operacyjnych"; 
$LANG['rulesengine'][68]="Dodatek serwisowy słowniki"; 
$LANG['rulesengine'][69]="Słownik wersji systemów operacyjnych"; 
$LANG['rulesengine'][70]="Zasady przydzielania zgłoszeń utworzonych przez odbiorców email"; 
$LANG['rulesengine'][76]="Uruchom słownikowanie"; 
$LANG['rulesengine'][77]="Słowniki"; 
$LANG['rulesengine'][78]="Wersja"; 
$LANG['rulesengine'][79]="Dodaj wyniki wyrażenia regularnego"; 
$LANG['rulesengine'][80]="Słownik globalny"; 
$LANG['rulesengine'][81]="Wynik reguły"; 
$LANG['rulesengine'][82]="Wyniki szczegółowo"; 
$LANG['rulesengine'][83]="Możesz wpłynąć na wyniki wyrażeń regularnych używając ciągu znaków #0"; 
$LANG['rulesengine'][84]="Testowanie reguł silnika"; 
$LANG['rulesengine'][85]="Wynik wyrażenia regularnego"; 
$LANG['rulesengine'][86]="Wymuszanie kategorii oprogramowania podczas usuwania ze słownika"; 
$LANG['rulesengine'][87]="Oprogramowanie usunięte przez słownik GLPI"; 
$LANG['rulesengine'][90]="Praca w toku..."; 
$LANG['rulesengine'][91]="Praca zakończona."; 
$LANG['rulesengine'][92]="Ostrzeżenie przed uruchomieniem słownika"; 
$LANG['rulesengine'][93]="Uwaga! Ta operacja może umieścić oprogramowanie w koszu.<br> Powiedz o tym swoim użytkownikom."; 
$LANG['rulesengine'][94]="FUZJA"; 
$LANG['rulesengine'][95]="Wybór producenta"; 
$LANG['rulesengine'][96]="Uruchom słownikowanie producenta(ów) <br> ( ----- = Wszystkie)"; 
$LANG['rulesengine'][97]="Żaden element nie został przetestowany"; 
$LANG['rulesengine'][100]="informacje tymczasowe"; 
$LANG['rulesengine'][102]="Nazwa reguły"; 
$LANG['rulesengine'][103]="Obiekty w cache"; 
$LANG['rulesengine'][104]="Orginalna wartość"; 
$LANG['rulesengine'][105]="Wartość zmodyfikowana"; 
$LANG['rulesengine'][106]="Niezmieniony"; 
$LANG['rulesengine'][107]="Nieaktywny"; 
$LANG['rulesengine'][108]="orginalny"; 
$LANG['rulesengine'][110]="Przydzielanie uprawnień"; 
$LANG['rulesengine'][111]="Przydzielanie oddziałów"; 
$LANG['rulesengine'][112]="Prawa i przydzielanie oddziałów"; 
$LANG['rulesengine'][120]="Silnik zatrzymuje się na pierwszej regule."; 
$LANG['rulesengine'][121]="Silnik traktuje wszystkie reguły."; 
$LANG['rulesengine'][122]="Silnik przekazuje rezultat reguły dalej."; 
$LANG['rulesengine'][130]="Oddział z LDAP"; 
$LANG['rulesengine'][131]="Oddział z TAG"; 
$LANG['rulesengine'][132]="Możliwe do zaimportowania w tle"; 
$LANG['rulesengine'][133]="Jednostki domen"; 
$LANG['rulesengine'][134]="Odrzuć wiadomość (bez powiadamiania email)"; 
$LANG['rulesengine'][135]="Odrzuć wiadomość (z powiadomieniem email)"; 
$LANG['rulesengine'][138]="Kryteria z LDAP"; 
$LANG['rulesengine'][140]="Dodano kryteria"; 
$LANG['rulesengine'][142]="Lista niezaimportowanych e-maili"; 
$LANG['rulesengine'][144]="Jednostka bazująca na profilu użytkownika"; 
$LANG['rulesengine'][145]="Użytkownik z pojedyńczym profilem"; 
$LANG['rulesengine'][146]="Charakterystyka profilu użytkownika"; 
$LANG['rulesengine'][147]="Charakterystyka użytkownika pojedynczego profilu"; 
$LANG['rulesengine'][148]="Znane domeny email"; 
$LANG['rulesengine'][150]="Zasady podłączone do oddziału zostały wyłączone."; 

$LANG['search'][0]="Szukaj"; 
$LANG['search'][1]="dla wszystkich"; 
$LANG['search'][2]="zawiera"; 
$LANG['search'][4]="Sortuj według"; 
$LANG['search'][8]="Data początkowa"; 
$LANG['search'][9]="Data końcowa"; 
$LANG['search'][10]="w"; 
$LANG['search'][11]="Widziane elementy"; 
$LANG['search'][12]="Wskaż datę końcową"; 
$LANG['search'][15]="Nie znaleziono pozycji"; 
$LANG['search'][16]="Co najmniej"; 
$LANG['search'][17]="Dodaj kryterium wyszukiwania"; 
$LANG['search'][18]="Skasuj kryterium wyszukiwania"; 
$LANG['search'][19]="Dodaj globalne kryteria wyszukiwania"; 
$LANG['search'][20]="Dodaj globalne kryteria wyszukiwania"; 

$LANG['setup'][0]="Listy rozwijalne"; 
$LANG['setup'][2]="Dodaj użytkownika"; 
$LANG['setup'][3]="Połączenie LDAP"; 
$LANG['setup'][4]="Typy komputerów"; 
$LANG['setup'][5]="System operacyjny"; 
$LANG['setup'][6]="Personalizacja"; 
$LANG['setup'][9]="Interfejsy sieciowe"; 
$LANG['setup'][10]="Wyświetlaj zamówienia z nazwiskiem i imieniem"; 
$LANG['setup'][14]="E-mail"; 
$LANG['setup'][18]="Logowanie"; 
$LANG['setup'][19]="Hasło"; 
$LANG['setup'][20]="Potwierdzenie hasła"; 
$LANG['setup'][21]="Błąd: hasła nie są identyczne"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Śledzenie domyślnie prywatne"; 
$LANG['setup'][40]="Domyślnie prywatne zadania"; 
$LANG['setup'][41]="Wybierz Język"; 
$LANG['setup'][42]="Typy sieci"; 
$LANG['setup'][43]="Typy drukarek"; 
$LANG['setup'][44]="Typy monitorów"; 
$LANG['setup'][45]="Typ obudowy"; 
$LANG['setup'][46]="Wartość domyślna"; 
$LANG['setup'][47]="Domyślny format wykresu"; 
$LANG['setup'][48]="Domyślne wartości"; 
$LANG['setup'][62]="Wybierz kategorię do konfigurowania"; 
$LANG['setup'][63]="Uwaga: chcesz usunąć nagłówek używany przez jeden lub więcej punktów"; 
$LANG['setup'][64]="Jeśli potwierdzisz usunięcie elementów, które używają tego nagłówka wartość zostanie wyczyszczona"; 
$LANG['setup'][65]="Możesz także zmienić wszystkie zdarzenia tego nagłówka dla:"; 
$LANG['setup'][67]="Zewnętrzna autentykacja"; 
$LANG['setup'][69]="Typy urządzeń"; 
$LANG['setup'][70]="Ustawienia ogólne"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Punkt Sieci"; 
$LANG['setup'][74]="Nie możesz usunąć pozycji, ponieważ posiada pod-pozycje"; 
$LANG['setup'][75]="Jako podrzędny"; 
$LANG['setup'][79]="Kategorie zgłoszeń"; 
$LANG['setup'][80]="Inne typy"; 
$LANG['setup'][81]="Nagłówki dokumentów"; 
$LANG['setup'][82]="Typ kontaktu"; 
$LANG['setup'][83]="Status pozycji"; 
$LANG['setup'][84]="Typ kartridża"; 
$LANG['setup'][85]="Typy umowów"; 
$LANG['setup'][86]="Typ pamięci"; 
$LANG['setup'][87]="Znane kategorie"; 
$LANG['setup'][88]="Sieć"; 
$LANG['setup'][89]="Domena"; 
$LANG['setup'][90]="VLANy"; 
$LANG['setup'][91]="Modele komputerów"; 
$LANG['setup'][92]="Typy materiałów eksploatacyjnych"; 
$LANG['setup'][93]="Interfejs dysku twardego"; 
$LANG['setup'][94]="Modele Monitorów"; 
$LANG['setup'][95]="Modele Sieciowe"; 
$LANG['setup'][96]="Modele Drukarek"; 
$LANG['setup'][97]="Modele peryferyjne"; 
$LANG['setup'][98]="Kategorie zadań"; 
$LANG['setup'][99]="Budowanie numeru"; 
$LANG['setup'][100]="Numer pokoju"; 
$LANG['setup'][101]="Maksymalna ilość zadań automatycznych"; 
$LANG['setup'][102]="Poziom Logowania"; 
$LANG['setup'][103]="1- Krytyczny (tylko błędy logowania)"; 
$LANG['setup'][104]="2- Ciężki (Nie używany)"; 
$LANG['setup'][105]="3- Ważny (poprawne logowania)"; 
$LANG['setup'][106]="4- Informacje (Dodanie, usunięcie, śledzenie)"; 
$LANG['setup'][107]="5- Całkowity (Wszystko)"; 
$LANG['setup'][109]="Jak długo logi maja zostać w bazie (w dniach, 0=bez ograniczeń)"; 
$LANG['setup'][110]="Pokaż nowe zgłoszenia na stronie głównej"; 
$LANG['setup'][111]="Maksymalna ilość wyników wyszukiwania na stronie"; 
$LANG['setup'][112]="Maksymalna liczba znaków dla każdej pozycji z listy"; 
$LANG['setup'][113]="Język domyslny"; 
$LANG['setup'][114]="Priorytet kolorów"; 
$LANG['setup'][115]="Domyślny próg wartości dla kaset i materiałów eksploatacyjnych"; 
$LANG['setup'][116]="Automatyczne przypisanie zgłoszeń do technika"; 
$LANG['setup'][117]="Zezwól na anonimowy wglądu w FAQ"; 
$LANG['setup'][118]="Tekst na stronie logowania"; 
$LANG['setup'][119]="Wyświetlanie"; 
$LANG['setup'][120]="Użyj dynamicznego wyświetlania dla pól tekstowych i list rozwijalnych"; 
$LANG['setup'][121]="Dynamiczne wyświetlanie wyrażeń reguralnych"; 
$LANG['setup'][122]="Maksymalna ilość pozycji widocznej w liście rozwijalnej"; 
$LANG['setup'][123]="Nie używaj dynamicznego wyświetlaniajeżeli liczba pozycji jest mniejsza niż"; 
$LANG['setup'][124]="Automatycznie dodaj uzytkowników z zewnętrznego źródła autoryzacji"; 
$LANG['setup'][125]="Z zewnętrznego źródła"; 
$LANG['setup'][126]="Automatycznie dodaj użytkownika z zewnętrznego źródła"; 
$LANG['setup'][127]="Automatyczne uzupełnianie pól tekstowych"; 
$LANG['setup'][128]="Format daty"; 
$LANG['setup'][129]="Pokaż ID GLPI"; 
$LANG['setup'][130]="ilość dni dla tej akcji zapisywanych do logów (0 dla wszystkich)"; 
$LANG['setup'][132]="Wyświetlaj kompletne nazwy w listach rozwijalnych"; 
$LANG['setup'][133]="Aktywuj tryb OCSNG"; 
$LANG['setup'][134]="OCS-Inventory"; 
$LANG['setup'][135]="Normalny"; 
$LANG['setup'][136]="Tłumaczenie"; 
$LANG['setup'][137]="Debagowanie"; 
$LANG['setup'][138]="Używaj GLPI w trybie"; 
$LANG['setup'][139]="Wspólne"; 
$LANG['setup'][140]="Typy"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamiczne wyświetlanie"; 
$LANG['setup'][148]="Krok dla godzin"; 
$LANG['setup'][149]="Pozycja dziesiętna w kwotach"; 
$LANG['setup'][150]="Numer Formatu"; 
$LANG['setup'][154]="Oparty na"; 
$LANG['setup'][155]="rootdn (dla nie anonimowych połączeń)"; 
$LANG['setup'][156]="Hasło (dla nie anonimowych połączeń)"; 
$LANG['setup'][157]="Rozszerzenie LDAP do twojego prasera PHP nie jest zainstalowane"; 
$LANG['setup'][158]="Niemożliwe użycie LDAP jako zewnętrznego źródła połączenia"; 
$LANG['setup'][159]="Filtr połączenia"; 
$LANG['setup'][162]="Konfiguracja IMAP/POP"; 
$LANG['setup'][164]="Nazwa hosta IMAP/POP (email może zostac użyty jako login@host )"; 
$LANG['setup'][165]="Twój interpreter PHP został skompilowany bez funkcji IMAP"; 
$LANG['setup'][166]="Niemożliwe użycie IMAP/POP jako zewnętrznego źródła połączenia"; 
$LANG['setup'][167]="Linki GLPI/katalog LDAP"; 
$LANG['setup'][168]="Opcje połączenia"; 
$LANG['setup'][169]="Folder Email (opcjonalnie,zazwyczaj INBOX)"; 
$LANG['setup'][170]="Parametry połączeniowe"; 
$LANG['setup'][171]="Port (opcjonalnie)"; 
$LANG['setup'][172]="Port LDAP (domyślnie=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Główny katalog (opcjonalnie)"; 
$LANG['setup'][177]="Konfiguracja CAS"; 
$LANG['setup'][178]="Rozszerzenie CURL lub DOMXML twojego parser-a PHP nie jest zainstalowane"; 
$LANG['setup'][179]="Niemożliwe użycie CAS jako zewnętrznego źródła połączenia"; 
$LANG['setup'][180]="Użyj TLS"; 
$LANG['setup'][181]="nie istnieje ldap_start_tls"; 
$LANG['setup'][182]="Adres URL przekierowania po wylogowaniu"; 
$LANG['setup'][185]="Logi w plikach (SQL, mail, akcje automatyczne itd.)"; 
$LANG['setup'][186]="Strefa czasowa"; 
$LANG['setup'][190]="certyfikat x509"; 
$LANG['setup'][191]="atrybuty dla mail x509"; 
$LANG['setup'][192]="Włączony"; 
$LANG['setup'][193]="Zaablokowane pole logowania w tablicy _SERVER"; 
$LANG['setup'][194]="Inne informacje pobrane z katalogu LDAP"; 
$LANG['setup'][195]="Utrzymaj status"; 
$LANG['setup'][196]="Wyczyść status"; 
$LANG['setup'][197]="Skopiuj status komputera"; 
$LANG['setup'][198]="Ustaw status"; 
$LANG['setup'][199]="Usuń domenę logowania w formie login@domena"; 
$LANG['setup'][200]="Nieskończony"; 
$LANG['setup'][201]="Konfiguracja funkcji"; 
$LANG['setup'][202]="Użyj śledzenia e-mail"; 
$LANG['setup'][203]="E-mail administratora"; 
$LANG['setup'][204]="Podpis e-mail"; 
$LANG['setup'][205]="E-mail wysłany do administratora"; 
$LANG['setup'][206]="Nie udane wysłanie e-maila do administratora"; 
$LANG['setup'][207]="Powiadamianie administratora przez email (jeżeli konieczne)"; 
$LANG['setup'][217]="Funkcja mail z PHP jest nie znana lub nie jest aktywna w Twoim systemie"; 
$LANG['setup'][218]="Użyj SMTP jeżeli potrzebne"; 
$LANG['setup'][219]="Pozwól wysyłać zgłoszenia anonimowo (helpdesk.receiver)"; 
$LANG['setup'][221]="Początek roku fiskalnego"; 
$LANG['setup'][223]="Limit dla okresowego planowania"; 
$LANG['setup'][227]="Adres internetowy aplikacji"; 
$LANG['setup'][228]="Pole logowania"; 
$LANG['setup'][229]="Spróbuj wysłać e-mail testowy do administratora"; 
$LANG['setup'][231]="Użyj serwera SMTP do wysyłania e-maili"; 
$LANG['setup'][232]="Host SMTP"; 
$LANG['setup'][234]="Użytkownik SMTP"; 
$LANG['setup'][235]="Hasło SMTP"; 
$LANG['setup'][236]="Koszt poprzedniego technika dla zgłoszenia"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Koszt technika dla tego zgłoszenia"; 
$LANG['setup'][240]="Opcje powiadomień"; 
$LANG['setup'][241]="Brak osobistych kryteriów. Utworzyć osobiste parametry?"; 
$LANG['setup'][242]="Opcje alarmów"; 
$LANG['setup'][243]="Alarmy materiałów eksploatacyjnych"; 
$LANG['setup'][244]="Alarmy kartridży"; 
$LANG['setup'][245]="Częstotliwość przypomnień"; 
$LANG['setup'][246]="Alarmy w umowach"; 
$LANG['setup'][247]="Alarmy finansowe"; 
$LANG['setup'][248]="Grupy zmieniające zgłoszenie"; 
$LANG['setup'][249]="Grupa odpowiedzi"; 
$LANG['setup'][250]="Domyślne pole listy wyszukiwania"; 
$LANG['setup'][252]="Wybierz domyślne elementy do pokazania"; 
$LANG['setup'][253]="Filtruj do szukania w grupach"; 
$LANG['setup'][254]="Typ szukania"; 
$LANG['setup'][255]="Grupa atrybutów zawierających użytkowników"; 
$LANG['setup'][256]="W użytkownikach"; 
$LANG['setup'][257]="W grupach"; 
$LANG['setup'][258]="Użytkownicy I Grupy"; 
$LANG['setup'][259]="Należące do grup"; 
$LANG['setup'][260]="Atrybut użytkownika zawarty w jego grupie"; 
$LANG['setup'][261]="Grupa DN"; 
$LANG['setup'][262]="Użyj DN w wyszukiwaniu"; 
$LANG['setup'][263]="Szukaj filtru dla użytkowników"; 
$LANG['setup'][264]="Alarmy wygaśniętych licencji"; 
$LANG['setup'][271]="Ograniczone zarządzanie monitorami"; 
$LANG['setup'][272]="Ograniczone zarządzanie urządzeniami"; 
$LANG['setup'][273]="Ograniczone zarządzanie telefonami"; 
$LANG['setup'][274]="dla dodania podręcznika"; 
$LANG['setup'][275]="Ograniczone zarządzanie drukarkami"; 
$LANG['setup'][280]="Automatyczne uaktualnianie elementów powiązanych z komputerami"; 
$LANG['setup'][281]="Podczas podłączania lub aktualizacji"; 
$LANG['setup'][282]="Podczas rozłączania"; 
$LANG['setup'][283]="Kopiuj"; 
$LANG['setup'][284]="Czyść"; 
$LANG['setup'][285]="Nie kopiować"; 
$LANG['setup'][286]="Nie usuwać"; 
$LANG['setup'][300]="Sprawdż czy jest dostępna nowa wersja"; 
$LANG['setup'][301]="Nowa wersja jest dostępna:"; 
$LANG['setup'][302]="Jest dostępne na stronie GLPI-PROJECT.org"; 
$LANG['setup'][303]="Posiadasz ostanią dostepną wersje"; 
$LANG['setup'][304]="Połączenie nieudane. Jeżeli używasz serwera proxy, proszę skonfiguruj to."; 
$LANG['setup'][305]="Każdego dnia"; 
$LANG['setup'][306]="Sprawdź aktualizacje"; 
$LANG['setup'][307]="Nigdy"; 
$LANG['setup'][308]="Co tydzień"; 
$LANG['setup'][309]="Co miesiąc"; 
$LANG['setup'][310]="Niemożliwe połączenie do punktu"; 
$LANG['setup'][311]="Nieudane połącznie do serwera proxy"; 
$LANG['setup'][312]="Brak dostępnych danych na stronie web"; 
$LANG['setup'][313]="Uwaga: to nie jest wartość domyślna"; 
$LANG['setup'][350]="Połącz pozycje ze stworzonym zgłoszeniem"; 
$LANG['setup'][351]="Wszystkie elementy"; 
$LANG['setup'][352]="Pozycje możliwe do połączenia ze zgłoszeniem"; 
$LANG['setup'][360]="Automatyczne pola (zaznaczone *)"; 
$LANG['setup'][400]="Konfiguracja proxy"; 
$LANG['setup'][407]="Link do uproszczonego środowiska Helpdesk"; 
$LANG['setup'][408]="Link do standardowego środowiska pomocy"; 
$LANG['setup'][409]="Domyślny nagłówek podczas dodawania dokumentu do zgłoszenia"; 
$LANG['setup'][503]="Modele telefonów"; 
$LANG['setup'][504]="Typy telefonów"; 
$LANG['setup'][505]="Typ zasilania telefonów"; 
$LANG['setup'][601]="Wartość LDAP"; 
$LANG['setup'][602]="Połączenie do bazy OCSNG"; 
$LANG['setup'][603]="Dodaj użytkownika"; 
$LANG['setup'][604]="Połącz z grupą"; 
$LANG['setup'][606]="Nie mogę dodać. Użytkownik istnieje."; 
$LANG['setup'][607]="Połączony z profilem"; 
$LANG['setup'][608]="Domyślnie oprogramowanie połączone ze zgłoszeniami"; 
$LANG['setup'][609]="Dodanie nie możliwe. Serwer OCS już istnieje."; 
$LANG['setup'][610]="Obowiązkowy tytuł zgłoszenia"; 
$LANG['setup'][611]="Obowiązkowa zawartość zgłoszenia"; 
$LANG['setup'][612]="Obowiązkowa kategoria zgłoszeń"; 
$LANG['setup'][613]="Dodaj użytkownika bez uprawnień LDAP"; 
$LANG['setup'][614]="Aktualizacja niemożliwa. Użytkownik już istnieje."; 
$LANG['setup'][615]="Cykl życia zgłoszenia"; 
$LANG['setup'][616]="Od \ Do"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Szukaj filtru dla oddziału"; 
$LANG['setup'][622]="Atrybuty reprezentujące oddział"; 
$LANG['setup'][623]="Importuj oddziały z LDAP"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Serwer pocztowy"; 
$LANG['setup'][661]="Konfiguracja powiadamiania niemożliwa, proszę włącz monitorowanie przez emaile"; 
$LANG['setup'][703]="Ustawienia"; 
$LANG['setup'][704]="Powiadomienia"; 
$LANG['setup'][707]="Alarmy rezerwacji"; 
$LANG['setup'][708]="Alarm w zgłoszeniach które nie są rozwiązane od"; 
$LANG['setup'][720]="Dane systemu"; 
$LANG['setup'][721]="Informacje o instalacji i konfiguracji"; 
$LANG['setup'][722]="Kopiuj/wklej do twojej odpowiedzi"; 
$LANG['setup'][731]="Wartość globalnej konfiguracji"; 
$LANG['setup'][732]="Domena wiadomości email"; 
$LANG['setup'][800]="Replikuj Mysql"; 
$LANG['setup'][801]="Włącz replikację MySQL"; 
$LANG['setup'][802]="Baza danych"; 
$LANG['setup'][803]="Różnice pomiędzy głównym i pomocniczym"; 
$LANG['setup'][806]="Maksymalna róznica pomiędzy głównym i zapasowym"; 
$LANG['setup'][807]="Baza zapasowa jest rozsynchronizowana. Różnice to:"; 
$LANG['setup'][808]="baza zapasowa jest rozsynchronizowana!"; 
$LANG['setup'][809]="Replika MySQL: tylko do odczytu"; 
$LANG['setup'][810]="Rozsynchronizowanie repliki MySQL"; 

$LANG['software'][1]="Zakup wersji"; 
$LANG['software'][2]="Użyj wersji"; 
$LANG['software'][3]="Nie zainstalowano licencji"; 
$LANG['software'][4]="nielimitowana"; 
$LANG['software'][5]="Wersje"; 
$LANG['software'][6]="Publikujący"; 
$LANG['software'][7]="Dodaj wersje"; 
$LANG['software'][8]="Dodaj licencje"; 
$LANG['software'][11]="Licencje"; 
$LANG['software'][17]="Zainstalowane oprogramowanie"; 
$LANG['software'][19]="Instalacje"; 
$LANG['software'][20]="Pozostało"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Uaktualnienie"; 
$LANG['software'][30]="Typ licencji"; 
$LANG['software'][32]="Wygaśnięcie licencji"; 
$LANG['software'][44]="Zainstaluj oprogramowanie"; 
$LANG['software'][45]="Odinstaluj oprogramowanie"; 
$LANG['software'][46]="Możliwy do wybrania w zgłoszeniu"; 
$LANG['software'][47]="Łączenie"; 
$LANG['software'][48]="Połącz"; 
$LANG['software'][49]="Oprogramowanie zostanie przeniesione do kosza po połączeniu"; 
$LANG['software'][50]="Połączone do komputera"; 
$LANG['software'][51]="Numer musi być 1 dla właczenia oddziaływania"; 

$LANG['softwarecategories'][2]="Oprogramowanie bez kategorii"; 
$LANG['softwarecategories'][3]="Rozwiń oprogramowanie bez kategorii"; 
$LANG['softwarecategories'][4]="Rozwiń kategorie oprogramowania"; 
$LANG['softwarecategories'][5]="Kategoria Oprogramowania"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Typ pozycji"; 
$LANG['state'][7]="Nie znaleziono pozycji"; 
$LANG['state'][11]="Podsumowanie"; 

$LANG['stats'][0]="Wybierz statystykę którą chcesz wyświetlić"; 
$LANG['stats'][1]="Globalne"; 
$LANG['stats'][2]="Brak pozycji do wyświetlenia"; 
$LANG['stats'][3]="Po częściach"; 
$LANG['stats'][5]="Liczba otwartych zgłoszeń"; 
$LANG['stats'][6]="Średnie opóźnienie w rozwiazaniu zgłoszeń"; 
$LANG['stats'][7]="Pokaż wykresy"; 
$LANG['stats'][11]="Liczba rozwiązanych zgłoszeń"; 
$LANG['stats'][13]="Liczba zgłoszeń"; 
$LANG['stats'][15]="Średnie opóźnienie w rozwiązaniu zgłoszenia"; 
$LANG['stats'][16]="Nazwa specjalisty"; 
$LANG['stats'][20]="Nazwa urzytkownika"; 
$LANG['stats'][23]="Brak statystyk"; 
$LANG['stats'][25]="Średni (rzeczywisty) czas rozwiązywania zgłoszenia"; 
$LANG['stats'][27]="Rzeczywisty czas 'życia' zgłoszenia"; 
$LANG['stats'][30]="Średni czas reakcji na zgłoszenie"; 
$LANG['stats'][31]="Dni(Dzień)"; 
$LANG['stats'][33]="Minut(a)"; 
$LANG['stats'][34]="Sekund(a)"; 
$LANG['stats'][35]="Zgłoszeń"; 
$LANG['stats'][44]="Nazwa dostawcy"; 
$LANG['stats'][45]="Po sprzęcie"; 
$LANG['stats'][47]="Po zgłoszeniach"; 
$LANG['stats'][48]="(przydzielone)"; 
$LANG['stats'][49]="(śledzenie)"; 

$LANG['title'][5]="Baza wiedzy"; 
$LANG['title'][6]="Sieć"; 
$LANG['title'][9]="Status pozycji"; 
$LANG['title'][10]="Śledzenie zgłoszeń"; 
$LANG['title'][13]="Informacje o urzytkowniku"; 
$LANG['title'][14]="Zewnętrzne źrudło autoryzacji"; 
$LANG['title'][24]="Wsparcie"; 
$LANG['title'][26]="Główny"; 
$LANG['title'][27]="Połączenia"; 
$LANG['title'][28]="Zgłoszenia"; 
$LANG['title'][30]="Komponenty"; 
$LANG['title'][33]="Linki zewnętrzne"; 
$LANG['title'][34]="Linki"; 
$LANG['title'][37]="Notatki"; 
$LANG['title'][38]="Historia"; 
$LANG['title'][40]="Publiczne i osobiste notatki"; 
$LANG['title'][42]="Masowa modyfikacja"; 
$LANG['title'][43]="Rejestr"; 

$LANG['tracking'][1]="Moje urządzenia"; 
$LANG['tracking'][2]="lub wyszukiwanie we wszystkich"; 
$LANG['tracking'][3]="Niepoprawne daty. Uaktualnienie anulowane."; 
$LANG['tracking'][4]="Nie ustawiłeś priorytetu zgłoszenia, proszę popraw to."; 
$LANG['tracking'][8]="Brak opisu w twoim zgłoszeniu, proszę spróbuj ponownie"; 
$LANG['tracking'][9]="Domyślne dla zgłoszeń"; 
$LANG['tracking'][10]="Domyślne dla odbiorców email"; 
$LANG['tracking'][24]="Dokument zgloszenia"; 
$LANG['tracking'][29]="Liczba"; 
$LANG['tracking'][30]="Nowy"; 
$LANG['tracking'][31]="W toku (przypisany)"; 
$LANG['tracking'][32]="W toku (zaplanowane)"; 
$LANG['tracking'][34]="Bezpośredni"; 
$LANG['tracking'][35]="Napisany"; 
$LANG['tracking'][37]="Pozostaw zgloszenia kiedy wyczyścisz sprzet z wyposażenia"; 
$LANG['tracking'][38]="Email został wysłany do"; 
$LANG['tracking'][39]="Widoczne dla uproszczonego środowiska"; 

$LANG['transfer'][1]="Przenoszenie"; 
$LANG['transfer'][3]="Jeżeli nie używany"; 
$LANG['transfer'][4]="Wyczyść listę elementów transferowanych"; 
$LANG['transfer'][5]="Możesz kontynuować aby dodać elementy do transferowanych lub transferować elementy teraz"; 
$LANG['transfer'][6]="Zrób backup przed transferowaniem elementów."; 
$LANG['transfer'][7]="Pozycja do przeniesienia"; 
$LANG['transfer'][8]="Tryb transferu"; 

$LANG['update'][88]="Wersja bazy danych nie jest kompatybilna z wersją zainstalowanego kodu. Konieczna jest aktualizacja."; 
$LANG['update'][89]="Próbujesz użyć GLPI z plikami z wcześniejszej wersji niż obecna wersja bazy danych. Proszę zainstaluj wersje plików odpowiednią dla twojej bazy danych."; 
$LANG['update'][90]="Błąd podczas update'u bazy danych"; 
$LANG['update'][91]="Uwaga !"; 
$LANG['update'][92]="Zaktualizujesz baze danych GLPI o nazwie:"; 
$LANG['update'][93]="Połączono z bazą danych"; 
$LANG['update'][94]="Odświeżenie udane, twoja baza jest aktualna."; 
$LANG['update'][95]="Połączenie z bazą danych nieudane, sprawdź parametry połączenia w pliku config_db.php"; 
$LANG['update'][96]="Teraz wszyscy administratorzy posiadają prawa 'super-admin'. Nowy użytkownik został również dodany."; 
$LANG['update'][105]="Update niemożliwy do osiągnięcia w ten sposób!!"; 
$LANG['update'][106]="Wróć do GLPI"; 
$LANG['update'][107]="Teraz musisz kontynuować odświerzanie zawartości twojej bazy danych"; 
$LANG['update'][130]="Aktualizacja lokalizacji"; 
$LANG['update'][131]="Nowa struktura jest hierarchiczna"; 
$LANG['update'][132]="Jeżeli starczy ci nerwów, możesz ustawić porządek dla automatycznego generowania nowych hierarchii."; 
$LANG['update'][133]="Możesz również ustawić główną lokalizacje która zawiera lokalizacje wygenerowane."; 
$LANG['update'][134]="Znak rozdzielający"; 
$LANG['update'][135]="Główna lokalizacja"; 
$LANG['update'][136]="TO jest nowa hierarchia. Jezeli jest ok możesz ją pozostawić."; 
$LANG['update'][137]="Nowa hierarchia"; 
$LANG['update'][138]="Obecne lokalizacje"; 
$LANG['update'][139]="Tabele optymalizacji"; 
$LANG['update'][140]="Tworzenie indeksów"; 
$LANG['update'][141]="Zmień schemat bazy danych"; 
$LANG['update'][142]="Przenoszenie danych"; 

$LANG['users'][1]="Nazwa"; 
$LANG['users'][2]="Kategoria"; 

$LANG['validation'][0]="Sprawdzanie"; 
$LANG['validation'][1]="Wyślij żądanie sprawdzenia"; 
$LANG['validation'][2]="Stan"; 
$LANG['validation'][3]="Data zgłoszenia"; 
$LANG['validation'][4]="Sprawdzanie daty"; 
$LANG['validation'][5]="Komentarz wysłany"; 
$LANG['validation'][6]="Sprawdzenie komentarza"; 
$LANG['validation'][7]="Sprawdzenie(a) zgłoszenia"; 
$LANG['validation'][9]="Oczekiwanie na sprawdzenie"; 
$LANG['validation'][10]="Odrzucono"; 
$LANG['validation'][11]="Zaakceptowane"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Żądanie sprawdzania wysłane do"; 
$LANG['validation'][15]="Zgłoszenie czeka na weryfikację."; 
$LANG['validation'][16]="Opcjonalne jeżeli zaakceptowane"; 
$LANG['validation'][18]="Sprawdzanie zgłaszającego"; 
$LANG['validation'][19]="Sprawdzanie zaakceptowane"; 
$LANG['validation'][20]="Sprawdzanie odrzucone"; 
$LANG['validation'][21]="Sprawdzanie użytkownika"; 
$LANG['validation'][23]="Wybrany użytkownik nie ma poprawnego adresu email. Zgłoszenie zostało utworzone, jednak powiadomienie email nie zostało wysłane."; 
$LANG['validation'][26]="Zgłoszenie sprawdzania"; 
$LANG['validation'][27]="Żądanie sprawdzenia zostało wysłane"; 
$LANG['validation'][28]="Status żądania sprawdzenia"; 
$LANG['validation'][29]="Jeżeli się nie zgadzasz, musisz podać powód"; 
$LANG['validation'][30]="Usuń żądanie sprawdzenia do"; 
$LANG['validation'][31]="Aktualizacja żądania zatwierdzenia do"; 
$LANG['validation'][32]="brak odpowiedzi w wykonywanym żądaniu weryfikacji"; 
$LANG['validation'][33]="Zgłoszenia czekające na twoje zatwierdzenie"; 
?>